/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_bg extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_gu = "\u0433\u0443\u0434\u0436\u0430\u0440\u0430\u0442\u0438";
        final String metaValue_he = "\u0438\u0432\u0440\u0438\u0442";
        final String metaValue_kn = "\u043a\u0430\u043d\u043d\u0430\u0434\u0430";
        final String metaValue_ml = "\u043c\u0430\u043b\u0430\u044f\u043b\u0430\u043c";
        final String metaValue_or = "\u043e\u0440\u0438\u044f";
        final String metaValue_te = "\u0442\u0435\u043b\u0443\u0433\u0443";
        final Object[][] data = new Object[][] {
            { "ksh", "\u043a\u044c\u043e\u043b\u043d\u0441\u043a\u0438" },
            { "Ogam", "\u041e\u0433\u0430\u043c\u0438\u0447\u0435\u0441\u043a\u0430" },
            { "mwl", "\u043c\u0438\u0440\u0430\u043d\u0434\u0438\u0439\u0441\u043a\u0438" },
            { "Zsym", "\u0441\u0438\u043c\u0432\u043e\u043b\u0438" },
            { "cch", "\u0430\u0442\u0441\u0430\u043c" },
            { "mwr", "\u043c\u0430\u0440\u0432\u0430\u0440\u0438" },
            { "Tagb", "\u0422\u0430\u0433\u0431\u0430\u043d\u0432\u0430" },
            { "Zsye", "\u0435\u043c\u043e\u0442\u0438\u043a\u043e\u043d\u0438" },
            { "%%NJIVA", "\u0414\u0438\u0430\u043b\u0435\u043a\u0442 \u041d\u0434\u0436\u0438\u0432\u0430" },
            { "egy", "\u0434\u0440\u0435\u0432\u043d\u043e\u0435\u0433\u0438\u043f\u0435\u0442\u0441\u043a\u0438" },
            { "raj", "\u0440\u0430\u0434\u0436\u0430\u0441\u0442\u0430\u043d\u0441\u043a\u0438" },
            { "Phag", "\u0424\u0430\u0433\u0441-\u043f\u0430" },
            { "tem", "\u0442\u0435\u043c\u043d\u0435" },
            { "teo", "\u0442\u0435\u0441\u043e" },
            { "rap", "\u0440\u0430\u043f\u0430 \u043d\u0443\u0438" },
            { "ter", "\u0442\u0435\u0440\u0435\u043d\u043e" },
            { "AC", "\u043e\u0441\u0442\u0440\u043e\u0432 \u0412\u044a\u0437\u043d\u0435\u0441\u0435\u043d\u0438\u0435" },
            { "rar", "\u0440\u0430\u0440\u043e\u0442\u043e\u043d\u0433\u0430" },
            { "tet", "\u0442\u0435\u0442\u0443\u043c" },
            { "AD", "\u0410\u043d\u0434\u043e\u0440\u0430" },
            { "AE", "\u041e\u0431\u0435\u0434\u0438\u043d\u0435\u043d\u0438 \u0430\u0440\u0430\u0431\u0441\u043a\u0438 \u0435\u043c\u0438\u0440\u0441\u0442\u0432\u0430" },
            { "nl_BE", "\u0444\u043b\u0430\u043c\u0430\u043d\u0434\u0441\u043a\u0438" },
            { "AF", "\u0410\u0444\u0433\u0430\u043d\u0438\u0441\u0442\u0430\u043d" },
            { "AG", "\u0410\u043d\u0442\u0438\u0433\u0443\u0430 \u0438 \u0411\u0430\u0440\u0431\u0443\u0434\u0430" },
            { "type.ca.ethiopic", "\u0435\u0442\u0438\u043e\u043f\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "AI", "\u0410\u043d\u0433\u0443\u0438\u043b\u0430" },
            { "key.tz", "\u0427\u0430\u0441\u043e\u0432\u0430 \u0437\u043e\u043d\u0430" },
            { "AL", "\u0410\u043b\u0431\u0430\u043d\u0438\u044f" },
            { "AM", "\u0410\u0440\u043c\u0435\u043d\u0438\u044f" },
            { "AO", "\u0410\u043d\u0433\u043e\u043b\u0430" },
            { "AQ", "\u0410\u043d\u0442\u0430\u0440\u043a\u0442\u0438\u043a\u0430" },
            { "AR", "\u0410\u0440\u0436\u0435\u043d\u0442\u0438\u043d\u0430" },
            { "AS", "\u0410\u043c\u0435\u0440\u0438\u043a\u0430\u043d\u0441\u043a\u0430 \u0421\u0430\u043c\u043e\u0430" },
            { "AT", "\u0410\u0432\u0441\u0442\u0440\u0438\u044f" },
            { "AU", "\u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f" },
            { "AW", "\u0410\u0440\u0443\u0431\u0430" },
            { "en_US", "\u0430\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438 (\u0421\u0410\u0429)" },
            { "AX", "\u041e\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "AZ", "\u0410\u0437\u0435\u0440\u0431\u0430\u0439\u0434\u0436\u0430\u043d" },
            { "%%AREVELA", "\u0418\u0437\u0442\u043e\u0447\u043d\u043e \u0430\u0440\u043c\u0435\u043d\u0441\u043a\u0438" },
            { "BA", "\u0411\u043e\u0441\u043d\u0430 \u0438 \u0425\u0435\u0440\u0446\u0435\u0433\u043e\u0432\u0438\u043d\u0430" },
            { "BB", "\u0411\u0430\u0440\u0431\u0430\u0434\u043e\u0441" },
            { "ceb", "\u0441\u0435\u0431\u0443\u0430\u043d\u0441\u043a\u0438" },
            { "BD", "\u0411\u0430\u043d\u0433\u043b\u0430\u0434\u0435\u0448" },
            { "kum", "\u043a\u0443\u043c\u0438\u043a\u0441\u043a\u0438" },
            { "BE", "\u0411\u0435\u043b\u0433\u0438\u044f" },
            { "gmh", "\u0441\u0440\u0435\u0434\u043d\u043e\u0432\u0438\u0441\u043e\u043a\u043e\u043d\u0435\u043c\u0441\u043a\u0438" },
            { "BF", "\u0411\u0443\u0440\u043a\u0438\u043d\u0430 \u0424\u0430\u0441\u043e" },
            { "BG", "\u0411\u044a\u043b\u0433\u0430\u0440\u0438\u044f" },
            { "BH", "\u0411\u0430\u0445\u0440\u0435\u0439\u043d" },
            { "BI", "\u0411\u0443\u0440\u0443\u043d\u0434\u0438" },
            { "BJ", "\u0411\u0435\u043d\u0438\u043d" },
            { "BL", "\u0421\u0435\u043d \u0411\u0430\u0440\u0442\u0435\u043b\u0435\u043c\u0438" },
            { "BM", "\u0411\u0435\u0440\u043c\u0443\u0434\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "kut", "\u043a\u0443\u0442\u0435\u043d\u0430\u0439" },
            { "myv", "\u0435\u0440\u0437\u0438\u0430" },
            { "BN", "\u0411\u0440\u0443\u043d\u0435\u0439 \u0414\u0430\u0440\u0443\u0441\u0441\u0430\u043b\u0430\u043c" },
            { "BO", "\u0411\u043e\u043b\u0438\u0432\u0438\u044f" },
            { "BQ", "\u041a\u0430\u0440\u0438\u0431\u0441\u043a\u0430 \u041d\u0438\u0434\u0435\u0440\u043b\u0430\u043d\u0434\u0438\u044f" },
            { "BR", "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u044f" },
            { "BS", "\u0411\u0430\u0445\u0430\u043c\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "xog", "\u0441\u043e\u0433\u0430" },
            { "BT", "\u0411\u0443\u0442\u0430\u043d" },
            { "BV", "\u043e\u0441\u0442\u0440\u043e\u0432 \u0411\u0443\u0432\u0435" },
            { "BW", "\u0411\u043e\u0442\u0441\u0432\u0430\u043d\u0430" },
            { "BY", "\u0411\u0435\u043b\u0430\u0440\u0443\u0441" },
            { "BZ", "\u0411\u0435\u043b\u0438\u0437" },
            { "Visp", "\u0412\u0438\u0434\u0438\u043c\u0430 \u0440\u0435\u0447" },
            { "type.ca.persian", "\u043f\u0435\u0440\u0441\u0438\u0439\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "type.nu.hebr", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u0438\u0432\u0440\u0438\u0442" },
            { "CA", "\u041a\u0430\u043d\u0430\u0434\u0430" },
            { "CC", "\u041a\u043e\u043a\u043e\u0441\u043e\u0432\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438 (\u043e\u0441\u0442\u0440\u043e\u0432\u0438 \u041a\u0438\u0439\u043b\u0438\u043d\u0433)" },
            { "mzn", "\u043c\u0430\u0437\u0430\u043d\u0434\u0430\u0440\u0438" },
            { "CD", "\u041a\u043e\u043d\u0433\u043e (\u041a\u0438\u043d\u0448\u0430\u0441\u0430)" },
            { "CF", "\u0426\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e\u0430\u0444\u0440\u0438\u043a\u0430\u043d\u0441\u043a\u0430 \u0440\u0435\u043f\u0443\u0431\u043b\u0438\u043a\u0430" },
            { "CG", "\u041a\u043e\u043d\u0433\u043e (\u0411\u0440\u0430\u0437\u0430\u0432\u0438\u043b)" },
            { "CH", "\u0428\u0432\u0435\u0439\u0446\u0430\u0440\u0438\u044f" },
            { "CI", "\u041a\u043e\u0442 \u0434\u2019\u0418\u0432\u043e\u0430\u0440" },
            { "CK", "\u043e\u0441\u0442\u0440\u043e\u0432\u0438 \u041a\u0443\u043a" },
            { "CL", "\u0427\u0438\u043b\u0438" },
            { "Kthi", "\u041a\u0430\u0439\u0442\u0445\u0438" },
            { "CM", "\u041a\u0430\u043c\u0435\u0440\u0443\u043d" },
            { "CN", "\u041a\u0438\u0442\u0430\u0439" },
            { "CO", "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u044f" },
            { "CP", "\u043e\u0441\u0442\u0440\u043e\u0432 \u041a\u043b\u0438\u043f\u0435\u0440\u0442\u043e\u043d" },
            { "CR", "\u041a\u043e\u0441\u0442\u0430 \u0420\u0438\u043a\u0430" },
            { "CU", "\u041a\u0443\u0431\u0430" },
            { "CV", "\u041a\u0430\u0431\u043e \u0412\u0435\u0440\u0434\u0435" },
            { "CW", "\u041a\u044e\u0440\u0430\u0441\u0430\u043e" },
            { "CX", "\u043e\u0441\u0442\u0440\u043e\u0432 \u0420\u043e\u0436\u0434\u0435\u0441\u0442\u0432\u043e" },
            { "CY", "\u041a\u0438\u043f\u044a\u0440" },
            { "CZ", "\u0427\u0435\u0445\u0438\u044f" },
            { "eka", "\u0435\u043a\u0430\u0436\u0443\u043a" },
            { "DE", "\u0413\u0435\u0440\u043c\u0430\u043d\u0438\u044f" },
            { "goh", "\u0441\u0442\u0430\u0440\u043e\u0432\u0438\u0441\u043e\u043a\u043e\u043d\u0435\u043c\u0441\u043a\u0438" },
            { "ace", "\u0430\u0447\u0435\u0448\u043a\u0438" },
            { "cgg", "\u0447\u0438\u0433\u0430" },
            { "DG", "\u0414\u0438\u0435\u0433\u043e \u0413\u0430\u0440\u0441\u0438\u044f" },
            { "type.nu.deva", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u0434\u0435\u0432\u0430\u043d\u0430\u0433\u0430\u0440\u0438" },
            { "DJ", "\u0414\u0436\u0438\u0431\u0443\u0442\u0438" },
            { "DK", "\u0414\u0430\u043d\u0438\u044f" },
            { "ach", "\u0430\u043a\u043e\u043b\u0438" },
            { "gon", "\u0433\u043e\u043d\u0434\u0438" },
            { "Brai", "\u0411\u0440\u0430\u0439\u043b\u043e\u0432\u0430" },
            { "Brah", "\u0411\u0440\u0430\u0445\u043c\u0438" },
            { "DM", "\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430" },
            { "type.nu.armnlow", "\u0430\u0440\u043c\u0435\u043d\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438 \u0432 \u0434\u043e\u043b\u0435\u043d \u0440\u0435\u0433\u0438\u0441\u0442\u044a\u0440" },
            { "DO", "\u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d\u0441\u043a\u0430 \u0440\u0435\u043f\u0443\u0431\u043b\u0438\u043a\u0430" },
            { "gor", "\u0433\u043e\u0440\u043e\u043d\u0442\u0430\u043b\u043e" },
            { "got", "\u0433\u043e\u0442\u0438\u0447\u0435\u0441\u043a\u0438" },
            { "Mtei", "\u041c\u0430\u043d\u0438\u043f\u0443\u0440\u0438" },
            { "zun", "\u0437\u0443\u043d\u0438" },
            { "tig", "\u0442\u0438\u0433\u0440\u0435" },
            { "DZ", "\u0410\u043b\u0436\u0438\u0440" },
            { "pag", "\u043f\u0430\u043d\u0433\u0430\u0441\u0438\u043d\u0430\u043d" },
            { "type.d0.hwidth", "\u0421 \u043f\u043e\u043b\u043e\u0432\u0438\u043d \u0448\u0438\u0440\u0438\u043d\u0430" },
            { "pal", "\u043f\u0430\u0445\u043b\u0430\u0432\u0438" },
            { "EA", "\u0421\u0435\u0443\u0442\u0430 \u0438 \u041c\u0435\u043b\u0438\u044f" },
            { "chb", "\u0447\u0438\u0431\u0447\u0430" },
            { "pam", "\u043f\u0430\u043c\u043f\u0430\u043d\u0433\u0430" },
            { "EC", "\u0415\u043a\u0432\u0430\u0434\u043e\u0440" },
            { "pap", "\u043f\u0430\u043f\u0438\u0430\u043c\u0435\u043d\u0442\u043e" },
            { "ada", "\u0430\u0434\u0430\u043d\u0433\u043c\u0435" },
            { "EE", "\u0415\u0441\u0442\u043e\u043d\u0438\u044f" },
            { "tiv", "\u0442\u0438\u0432" },
            { "EG", "\u0415\u0433\u0438\u043f\u0435\u0442" },
            { "EH", "\u0417\u0430\u043f\u0430\u0434\u043d\u0430 \u0421\u0430\u0445\u0430\u0440\u0430" },
            { "chg", "\u0447\u0430\u0433\u0430\u0442\u0430\u0439" },
            { "pau", "\u043f\u0430\u043b\u0430\u0443\u0430\u043d" },
            { "chk", "\u0447\u0443\u0443\u043a" },
            { "chn", "\u0436\u0430\u0440\u0433\u043e\u043d \u0447\u0438\u043d\u0443\u0443\u043a" },
            { "chm", "\u043c\u0430\u0440\u0438\u0439\u0441\u043a\u0438" },
            { "chp", "\u0447\u0438\u0438\u043f\u0443\u0432\u0441\u043a\u0438" },
            { "cho", "\u0447\u043e\u043a\u0442\u043e" },
            { "chr", "\u0447\u0435\u0440\u043e\u043a\u0441\u043a\u0438" },
            { "ER", "\u0415\u0440\u0438\u0442\u0440\u0435\u044f" },
            { "ES", "\u0418\u0441\u043f\u0430\u043d\u0438\u044f" },
            { "ET", "\u0415\u0442\u0438\u043e\u043f\u0438\u044f" },
            { "EU", "\u0415\u0432\u0440\u043e\u043f\u0435\u0439\u0441\u043a\u0438 \u0441\u044a\u044e\u0437" },
            { "elx", "\u0435\u043b\u0430\u043c\u0438\u0442\u0441\u043a\u0438" },
            { "type.ca.gregorian", "\u0433\u0440\u0438\u0433\u043e\u0440\u0438\u0430\u043d\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "EZ", "\u0415\u0432\u0440\u043e\u0437\u043e\u043d\u0430" },
            { "chy", "\u0448\u0430\u0439\u0435\u043d\u0441\u043a\u0438" },
            { "type.nu.gujr", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u0433\u0443\u0434\u0436\u0430\u0440\u0430\u0442\u0438" },
            { "Inds", "\u0425\u0430\u0440\u0430\u043f\u0441\u043a\u0430" },
            { "ady", "\u0430\u0434\u0438\u0433\u0435\u0439\u0441\u043a\u0438" },
            { "FI", "\u0424\u0438\u043d\u043b\u0430\u043d\u0434\u0438\u044f" },
            { "FJ", "\u0424\u0438\u0434\u0436\u0438" },
            { "FK", "\u0424\u043e\u043b\u043a\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "FM", "\u041c\u0438\u043a\u0440\u043e\u043d\u0435\u0437\u0438\u044f" },
            { "key.va", "\u0412\u0430\u0440\u0438\u0430\u043d\u0442 \u043d\u0430 \u043b\u043e\u043a\u0430\u043b\u0430" },
            { "FO", "\u0424\u0430\u0440\u044c\u043e\u0440\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "Taml", "\u0442\u0430\u043c\u0438\u043b\u0441\u043a\u0430" },
            { "FR", "\u0424\u0440\u0430\u043d\u0446\u0438\u044f" },
            { "tkl", "\u0442\u043e\u043a\u0435\u043b\u0430\u0439\u0441\u043a\u0438" },
            { "grb", "\u0433\u0440\u0435\u0431\u043e" },
            { "root", "\u0440\u043e\u043e\u0442" },
            { "type.ca.indian", "\u0418\u043d\u0434\u0438\u0439\u0441\u043a\u0438 \u0433\u0440\u0430\u0436\u0434\u0430\u043d\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "grc", "\u0434\u0440\u0435\u0432\u043d\u043e\u0433\u0440\u044a\u0446\u043a\u0438" },
            { "GA", "\u0413\u0430\u0431\u043e\u043d" },
            { "vot", "\u0432\u043e\u0442\u0438\u043a" },
            { "GB", "\u041e\u0431\u0435\u0434\u0438\u043d\u0435\u043d\u043e\u0442\u043e \u043a\u0440\u0430\u043b\u0441\u0442\u0432\u043e" },
            { "pcm", "\u043d\u0438\u0433\u0435\u0440\u0438\u0439\u0441\u043a\u0438 \u043f\u0438\u0434\u0436\u0438\u043d" },
            { "GD", "\u0413\u0440\u0435\u043d\u0430\u0434\u0430" },
            { "GE", "\u0413\u0440\u0443\u0437\u0438\u044f" },
            { "GF", "\u0424\u0440\u0435\u043d\u0441\u043a\u0430 \u0413\u0432\u0438\u0430\u043d\u0430" },
            { "GG", "\u0413\u044a\u0440\u043d\u0437\u0438" },
            { "GH", "\u0413\u0430\u043d\u0430" },
            { "Tale", "\u0422\u0430\u0439 \u041b\u0435" },
            { "GI", "\u0413\u0438\u0431\u0440\u0430\u043b\u0442\u0430\u0440" },
            { "afh", "\u0430\u0444\u0440\u0438\u0445\u0438\u043b\u0438" },
            { "GL", "\u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f" },
            { "enm", "\u0441\u0440\u0435\u0434\u043d\u043e\u0432\u0435\u043a\u043e\u0432\u0435\u043d \u0430\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438" },
            { "GM", "\u0413\u0430\u043c\u0431\u0438\u044f" },
            { "GN", "\u0413\u0432\u0438\u043d\u0435\u044f" },
            { "GP", "\u0413\u0432\u0430\u0434\u0435\u043b\u0443\u043f\u0430" },
            { "GQ", "\u0415\u043a\u0432\u0430\u0442\u043e\u0440\u0438\u0430\u043b\u043d\u0430 \u0413\u0432\u0438\u043d\u0435\u044f" },
            { "GR", "\u0413\u044a\u0440\u0446\u0438\u044f" },
            { "GS", "\u042e\u0436\u043d\u0430 \u0414\u0436\u043e\u0440\u0434\u0436\u0438\u044f \u0438 \u042e\u0436\u043d\u0438 \u0421\u0430\u043d\u0434\u0432\u0438\u0447\u0435\u0432\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "GT", "\u0413\u0432\u0430\u0442\u0435\u043c\u0430\u043b\u0430" },
            { "GU", "\u0413\u0443\u0430\u043c" },
            { "GW", "\u0413\u0432\u0438\u043d\u0435\u044f-\u0411\u0438\u0441\u0430\u0443" },
            { "tli", "\u0442\u043b\u0438\u043d\u0433\u0438\u0442" },
            { "tlh", "\u043a\u043b\u0438\u043d\u0433\u043e\u043d\u0441\u043a\u0438" },
            { "Talu", "\u041d\u043e\u0432\u0430 \u0422\u0430\u0439 \u041b\u0435" },
            { "GY", "\u0413\u0430\u044f\u043d\u0430" },
            { "ckb", "\u043a\u044e\u0440\u0434\u0441\u043a\u0438 (\u0446\u0435\u043d\u0442\u0440\u0430\u043b\u0435\u043d)" },
            { "zxx", "\u0431\u0435\u0437 \u043b\u0438\u043d\u0433\u0432\u0438\u0441\u0442\u0438\u0447\u043d\u043e \u0441\u044a\u0434\u044a\u0440\u0436\u0430\u043d\u0438\u0435" },
            { "HK", "\u0425\u043e\u043d\u043a\u043e\u043d\u0433, \u0421\u0410\u0420 \u043d\u0430 \u041a\u0438\u0442\u0430\u0439" },
            { "Vaii", "\u0412\u0430\u0439\u0441\u043a\u0430" },
            { "HM", "\u043e\u0441\u0442\u0440\u043e\u0432\u0438 \u0425\u044a\u0440\u0434 \u0438 \u041c\u0430\u043a\u0434\u043e\u043d\u0430\u043b\u0434" },
            { "HN", "\u0425\u043e\u043d\u0434\u0443\u0440\u0430\u0441" },
            { "HR", "\u0425\u044a\u0440\u0432\u0430\u0442\u0438\u044f" },
            { "agq", "\u0430\u0433\u0435\u043c" },
            { "gsw", "\u0448\u0432\u0435\u0439\u0446\u0430\u0440\u0441\u043a\u0438 \u043d\u0435\u043c\u0441\u043a\u0438" },
            { "HT", "\u0425\u0430\u0438\u0442\u0438" },
            { "HU", "\u0423\u043d\u0433\u0430\u0440\u0438\u044f" },
            { "tmh", "\u0442\u0430\u043c\u0430\u0448\u0435\u043a" },
            { "IC", "\u041a\u0430\u043d\u0430\u0440\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "ID", "\u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u044f" },
            { "peo", "\u0441\u0442\u0430\u0440\u043e\u043f\u0435\u0440\u0441\u0438\u0439\u0441\u043a\u0438" },
            { "IE", "\u0418\u0440\u043b\u0430\u043d\u0434\u0438\u044f" },
            { "nap", "\u043d\u0435\u0430\u043f\u043e\u043b\u0438\u0442\u0430\u043d\u0441\u043a\u0438" },
            { "naq", "\u043d\u0430\u043c\u0430" },
            { "zza", "\u0437\u0430\u0437\u0430" },
            { "IL", "\u0418\u0437\u0440\u0430\u0435\u043b" },
            { "IM", "\u043e\u0441\u0442\u0440\u043e\u0432 \u041c\u0430\u043d" },
            { "IN", "\u0418\u043d\u0434\u0438\u044f" },
            { "IO", "\u0411\u0440\u0438\u0442\u0430\u043d\u0441\u043a\u0430 \u0442\u0435\u0440\u0438\u0442\u043e\u0440\u0438\u044f \u0432 \u0418\u043d\u0434\u0438\u0439\u0441\u043a\u0438\u044f \u043e\u043a\u0435\u0430\u043d" },
            { "IQ", "\u0418\u0440\u0430\u043a" },
            { "IR", "\u0418\u0440\u0430\u043d" },
            { "IS", "\u0418\u0441\u043b\u0430\u043d\u0434\u0438\u044f" },
            { "IT", "\u0418\u0442\u0430\u043b\u0438\u044f" },
            { "Zmth", "\u041c\u0430\u0442\u0435\u043c\u0430\u0442\u0438\u0447\u0435\u0441\u043a\u0438 \u0441\u0438\u043c\u0432\u043e\u043b\u0438" },
            { "type.nu.thai", "\u0442\u0430\u0439\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "%%POSIX", "\u041a\u043e\u043c\u043f\u044e\u0442\u044a\u0440\u0435\u043d" },
            { "type.nu.beng", "\u0431\u0435\u043d\u0433\u0430\u043b\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "JE", "\u0414\u0436\u044a\u0440\u0441\u0438" },
            { "type.ca.islamic", "\u0438\u0441\u043b\u044f\u043c\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "JM", "\u042f\u043c\u0430\u0439\u043a\u0430" },
            { "Beng", "\u0431\u0435\u043d\u0433\u0430\u043b\u0441\u043a\u0430" },
            { "JO", "\u0419\u043e\u0440\u0434\u0430\u043d\u0438\u044f" },
            { "JP", "\u042f\u043f\u043e\u043d\u0438\u044f" },
            { "%%1606NICT", "\u041a\u044a\u0441\u0435\u043d \u0441\u0440\u0435\u0434\u043d\u043e\u0432\u0435\u043a\u043e\u0432\u0435\u043d \u0444\u0440\u0435\u043d\u0441\u043a\u0438 \u0434\u043e 1606" },
            { "ain", "\u0430\u0439\u043d\u0443" },
            { "guz", "\u0433\u0443\u0441\u0438\u0438" },
            { "tog", "\u043d\u0438\u0430\u043d\u0441\u0430 \u0442\u043e\u043d\u0433\u0430" },
            { "type.nu.knda", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u043a\u0430\u043d\u043d\u0430\u0434\u0430" },
            { "Kali", "\u041a\u0430\u044f \u041b\u0438" },
            { "type.co.phonetic", "\u0424\u043e\u043d\u0435\u0442\u0438\u0447\u0435\u043d \u0440\u0435\u0434 \u043d\u0430 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u043d\u0435" },
            { "type.ca.buddhist", "\u0431\u0443\u0434\u0438\u0441\u0442\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "KE", "\u041a\u0435\u043d\u0438\u044f" },
            { "419", "\u041b\u0430\u0442\u0438\u043d\u0441\u043a\u0430 \u0410\u043c\u0435\u0440\u0438\u043a\u0430" },
            { "KG", "\u041a\u0438\u0440\u0433\u0438\u0437\u0441\u0442\u0430\u043d" },
            { "KH", "\u041a\u0430\u043c\u0431\u043e\u0434\u0436\u0430" },
            { "KI", "\u041a\u0438\u0440\u0438\u0431\u0430\u0442\u0438" },
            { "KM", "\u041a\u043e\u043c\u043e\u0440\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "Knda", metaValue_kn },
            { "KN", "\u0421\u0435\u0439\u043d\u0442 \u041a\u0438\u0442\u0441 \u0438 \u041d\u0435\u0432\u0438\u0441" },
            { "KP", "\u0421\u0435\u0432\u0435\u0440\u043d\u0430 \u041a\u043e\u0440\u0435\u044f" },
            { "KR", "\u042e\u0436\u043d\u0430 \u041a\u043e\u0440\u0435\u044f" },
            { "Plrd", "\u041f\u0438\u0441\u043c\u0435\u043d\u043e\u0441\u0442 \u041f\u043e\u043b\u0430\u0440\u0434" },
            { "KW", "\u041a\u0443\u0432\u0435\u0439\u0442" },
            { "tpi", "\u0442\u043e\u043a \u043f\u0438\u0441\u0438\u043d" },
            { "KY", "\u041a\u0430\u0439\u043c\u0430\u043d\u043e\u0432\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "KZ", "\u041a\u0430\u0437\u0430\u0445\u0441\u0442\u0430\u043d" },
            { "Cyrl", "\u043a\u0438\u0440\u0438\u043b\u0438\u0446\u0430" },
            { "LA", "\u041b\u0430\u043e\u0441" },
            { "LB", "\u041b\u0438\u0432\u0430\u043d" },
            { "LC", "\u0421\u0435\u0439\u043d\u0442 \u041b\u0443\u0441\u0438\u044f" },
            { "phn", "\u0444\u0438\u043d\u0438\u043a\u0438\u0439\u0441\u043a\u0438" },
            { "gwi", "\u0433\u0432\u0438\u0447\u0438\u043d" },
            { "nds", "\u0434\u043e\u043b\u043d\u043e\u043d\u0435\u043c\u0441\u043a\u0438" },
            { "LI", "\u041b\u0438\u0445\u0442\u0435\u043d\u0449\u0430\u0439\u043d" },
            { "LK", "\u0428\u0440\u0438 \u041b\u0430\u043d\u043a\u0430" },
            { "akk", "\u0430\u043a\u0430\u0434\u0441\u043a\u0438" },
            { "cop", "\u043a\u043e\u043f\u0442\u0441\u043a\u0438" },
            { "LR", "\u041b\u0438\u0431\u0435\u0440\u0438\u044f" },
            { "LS", "\u041b\u0435\u0441\u043e\u0442\u043e" },
            { "Phlv", "\u041f\u0430\u0445\u043b\u0430\u0432\u0441\u043a\u0430" },
            { "LT", "\u041b\u0438\u0442\u0432\u0430" },
            { "LU", "\u041b\u044e\u043a\u0441\u0435\u043c\u0431\u0443\u0440\u0433" },
            { "LV", "\u041b\u0430\u0442\u0432\u0438\u044f" },
            { "Kana", "\u043a\u0430\u0442\u0430\u043a\u0430\u043d\u0430" },
            { "LY", "\u041b\u0438\u0431\u0438\u044f" },
            { "lad", "\u043b\u0430\u0434\u0438\u043d\u043e" },
            { "vun", "\u0432\u0443\u043d\u0434\u0436\u043e" },
            { "lah", "\u043b\u0430\u0445\u043d\u0434\u0430" },
            { "lag", "\u043b\u0430\u043d\u0433\u0438" },
            { "Thaa", "\u0442\u0430\u0430\u043d\u0430" },
            { "MA", "\u041c\u0430\u0440\u043e\u043a\u043e" },
            { "MC", "\u041c\u043e\u043d\u0430\u043a\u043e" },
            { "MD", "\u041c\u043e\u043b\u0434\u043e\u0432\u0430" },
            { "ME", "\u0427\u0435\u0440\u043d\u0430 \u0433\u043e\u0440\u0430" },
            { "MF", "\u0421\u0435\u043d \u041c\u0430\u0440\u0442\u0435\u043d" },
            { "lam", "\u043b\u0430\u043c\u0431\u0430" },
            { "MG", "\u041c\u0430\u0434\u0430\u0433\u0430\u0441\u043a\u0430\u0440" },
            { "MH", "\u041c\u0430\u0440\u0448\u0430\u043b\u043e\u0432\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "ale", "\u0430\u043b\u0435\u0443\u0442\u0441\u043a\u0438" },
            { "Thai", "\u0442\u0430\u0439\u0441\u043a\u0430" },
            { "type.nu.vaii", "\u0426\u0438\u0444\u0440\u0438 \u0432\u044a\u0432 \u0432\u0430\u0438" },
            { "MK", "\u0421\u0435\u0432\u0435\u0440\u043d\u0430 \u041c\u0430\u043a\u0435\u0434\u043e\u043d\u0438\u044f" },
            { "ML", "\u041c\u0430\u043b\u0438" },
            { "MM", "\u041c\u0438\u0430\u043d\u043c\u0430\u0440 (\u0411\u0438\u0440\u043c\u0430)" },
            { "MN", "\u041c\u043e\u043d\u0433\u043e\u043b\u0438\u044f" },
            { "new", "\u043d\u0435\u0432\u0430\u0440\u0441\u043a\u0438" },
            { "MO", "\u041c\u0430\u043a\u0430\u043e, \u0421\u0410\u0420 \u043d\u0430 \u041a\u0438\u0442\u0430\u0439" },
            { "MP", "\u0421\u0435\u0432\u0435\u0440\u043d\u0438 \u041c\u0430\u0440\u0438\u0430\u043d\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "MQ", "\u041c\u0430\u0440\u0442\u0438\u043d\u0438\u043a\u0430" },
            { "MR", "\u041c\u0430\u0432\u0440\u0438\u0442\u0430\u043d\u0438\u044f" },
            { "MS", "\u041c\u043e\u043d\u0442\u0441\u0435\u0440\u0430\u0442" },
            { "MT", "\u041c\u0430\u043b\u0442\u0430" },
            { "type.m0.ungegn", "\u0413\u0415\u0421\u0413\u0418 \u041e\u041e\u041d (UNGEGN)" },
            { "MU", "\u041c\u0430\u0432\u0440\u0438\u0446\u0438\u0439" },
            { "alt", "\u044e\u0436\u043d\u043e\u0430\u043b\u0442\u0430\u0439\u0441\u043a\u0438" },
            { "MV", "\u041c\u0430\u043b\u0434\u0438\u0432\u0438" },
            { "MW", "\u041c\u0430\u043b\u0430\u0432\u0438" },
            { "MX", "\u041c\u0435\u043a\u0441\u0438\u043a\u043e" },
            { "type.ca.japanese", "\u044f\u043f\u043e\u043d\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "MY", "\u041c\u0430\u043b\u0430\u0439\u0437\u0438\u044f" },
            { "MZ", "\u041c\u043e\u0437\u0430\u043c\u0431\u0438\u043a" },
            { "NA", "\u041d\u0430\u043c\u0438\u0431\u0438\u044f" },
            { "202", "\u0421\u0443\u0431\u0441\u0430\u0445\u0430\u0440\u0441\u043a\u0430 \u0410\u0444\u0440\u0438\u043a\u0430" },
            { "type.ca.hebrew", "\u0435\u0432\u0440\u0435\u0439\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "type.co.dictionary", "\u0420\u0435\u0447\u043d\u0438\u043a\u043e\u0432 \u0440\u0435\u0434 \u043d\u0430 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u043d\u0435" },
            { "NC", "\u041d\u043e\u0432\u0430 \u041a\u0430\u043b\u0435\u0434\u043e\u043d\u0438\u044f" },
            { "%%WADEGILE", "\u0423\u0435\u0439\u0434-\u0414\u0436\u0430\u0439\u043b\u0441 \u0440\u043e\u043c\u0430\u043d\u0438\u0437\u0430\u0446\u0438\u044f" },
            { "NE", "\u041d\u0438\u0433\u0435\u0440" },
            { "NF", "\u043e\u0441\u0442\u0440\u043e\u0432 \u041d\u043e\u0440\u0444\u043e\u043b\u043a" },
            { "NG", "\u041d\u0438\u0433\u0435\u0440\u0438\u044f" },
            { "trv", "\u0442\u0430\u0440\u043e\u043a\u043e" },
            { "NI", "\u041d\u0438\u043a\u0430\u0440\u0430\u0433\u0443\u0430" },
            { "Hmng", "\u041f\u0430\u0445\u0430\u0443 \u0445\u043c\u043e\u043d\u0433" },
            { "NL", "\u041d\u0438\u0434\u0435\u0440\u043b\u0430\u043d\u0434\u0438\u044f" },
            { "NO", "\u041d\u043e\u0440\u0432\u0435\u0433\u0438\u044f" },
            { "NP", "\u041d\u0435\u043f\u0430\u043b" },
            { "NR", "\u041d\u0430\u0443\u0440\u0443" },
            { "NU", "\u041d\u0438\u0443\u0435" },
            { "Phnx", "\u0424\u0438\u043d\u0438\u043a\u0438\u0439\u0441\u043a\u0430" },
            { "rof", "\u0440\u043e\u043c\u0431\u043e" },
            { "tsi", "\u0446\u0438\u043c\u0448\u0438\u0430\u043d\u0441\u043a\u0438" },
            { "NZ", "\u041d\u043e\u0432\u0430 \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f" },
            { "rom", "\u0440\u043e\u043c\u0441\u043a\u0438" },
            { "Mero", "\u041c\u0435\u0440\u043e\u0438\u0442\u0441\u043a\u0430" },
            { "crh", "\u043a\u0440\u0438\u043c\u0441\u043a\u043e\u0442\u0430\u0442\u0430\u0440\u0441\u043a\u0438" },
            { "ang", "\u0441\u0442\u0430\u0440\u043e\u0430\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438" },
            { "OM", "\u041e\u043c\u0430\u043d" },
            { "anp", "\u0430\u043d\u0433\u0438\u043a\u0430" },
            { "crs", "\u0441\u0435\u0441\u0435\u043b\u0432\u0430, \u043a\u0440\u0435\u043e\u043b\u0441\u043a\u0438 \u0444\u0440\u0435\u043d\u0441\u043a\u0438" },
            { "Xpeo", "\u0421\u0442\u0430\u0440\u043e\u043f\u0435\u0440\u0441\u0438\u0439\u0441\u043a\u0430" },
            { "PA", "\u041f\u0430\u043d\u0430\u043c\u0430" },
            { "type.ca.islamic-civil", "\u0418\u0441\u043b\u044f\u043c\u0441\u043a\u0438 \u0446\u0438\u0432\u0438\u043b\u0435\u043d \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "csb", "\u043a\u0430\u0448\u0443\u0431\u0441\u043a\u0438" },
            { "PE", "\u041f\u0435\u0440\u0443" },
            { "PF", "\u0424\u0440\u0435\u043d\u0441\u043a\u0430 \u041f\u043e\u043b\u0438\u043d\u0435\u0437\u0438\u044f" },
            { "PG", "\u041f\u0430\u043f\u0443\u0430-\u041d\u043e\u0432\u0430 \u0413\u0432\u0438\u043d\u0435\u044f" },
            { "PH", "\u0424\u0438\u043b\u0438\u043f\u0438\u043d\u0438" },
            { "PK", "\u041f\u0430\u043a\u0438\u0441\u0442\u0430\u043d" },
            { "PL", "\u041f\u043e\u043b\u0448\u0430" },
            { "ewo", "\u0435\u0432\u043e\u043d\u0434\u043e" },
            { "PM", "\u0421\u0435\u043d \u041f\u0438\u0435\u0440 \u0438 \u041c\u0438\u043a\u0435\u043b\u043e\u043d" },
            { "PN", "\u041e\u0441\u0442\u0440\u043e\u0432\u0438 \u041f\u0438\u0442\u043a\u0435\u0440\u043d" },
            { "PR", "\u041f\u0443\u0435\u0440\u0442\u043e \u0420\u0438\u043a\u043e" },
            { "PS", "\u041f\u0430\u043b\u0435\u0441\u0442\u0438\u043d\u0441\u043a\u0438 \u0442\u0435\u0440\u0438\u0442\u043e\u0440\u0438\u0438" },
            { "Bali", "\u0411\u0430\u043b\u0438\u0439\u0441\u043a\u0438" },
            { "PT", "\u041f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u0438\u044f" },
            { "PW", "\u041f\u0430\u043b\u0430\u0443" },
            { "nia", "\u043d\u0438\u0430\u0441" },
            { "type.nu.greklow", "\u0433\u0440\u044a\u0446\u043a\u0438 \u0446\u0438\u0444\u0440\u0438 \u0432 \u0434\u043e\u043b\u0435\u043d \u0440\u0435\u0433\u0438\u0441\u0442\u044a\u0440" },
            { "PY", "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0439" },
            { "tum", "\u0442\u0443\u043c\u0431\u0443\u043a\u0430" },
            { "Hebr", metaValue_he },
            { "QA", "\u041a\u0430\u0442\u0430\u0440" },
            { "%%SCOTLAND", "\u0428\u043e\u0442\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u0430\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438" },
            { "niu", "\u043d\u0438\u0443\u0435\u0430\u043d" },
            { "QO", "\u041e\u0442\u0434\u0430\u043b\u0435\u0447\u0435\u043d\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438 \u043d\u0430 \u041e\u043a\u0435\u0430\u043d\u0438\u044f" },
            { "lez", "\u043b\u0435\u0437\u0433\u0438\u043d\u0441\u043a\u0438" },
            { "%%FONUPA", "\u0423\u0440\u0430\u043b\u0441\u043a\u0430 \u0444\u043e\u043d\u0435\u0442\u0438\u0447\u043d\u0430 \u0430\u0437\u0431\u0443\u043a\u0430" },
            { "tvl", "\u0442\u0443\u0432\u0430\u043b\u0443\u0430\u043d\u0441\u043a\u0438" },
            { "001", "\u0421\u0432\u044f\u0442" },
            { "002", "\u0410\u0444\u0440\u0438\u043a\u0430" },
            { "003", "\u0421\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u043a\u043e\u043d\u0442\u0438\u043d\u0435\u043d\u0442" },
            { "RE", "\u0420\u0435\u044e\u043d\u0438\u043e\u043d" },
            { "005", "\u042e\u0436\u043d\u0430 \u0410\u043c\u0435\u0440\u0438\u043a\u0430" },
            { "jbo", "\u043b\u043e\u0436\u0431\u0430\u043d" },
            { "009", "\u041e\u043a\u0435\u0430\u043d\u0438\u044f" },
            { "RO", "\u0420\u0443\u043c\u044a\u043d\u0438\u044f" },
            { "RS", "\u0421\u044a\u0440\u0431\u0438\u044f" },
            { "RU", "\u0420\u0443\u0441\u0438\u044f" },
            { "RW", "\u0420\u0443\u0430\u043d\u0434\u0430" },
            { "Mani", "\u041c\u0430\u043d\u0438\u0445\u0435\u0439\u0441\u043a\u0430" },
            { "Ugar", "\u0423\u0433\u0430\u0440\u0438\u0442\u0441\u043a\u0430" },
            { "Khar", "\u041a\u0445\u0430\u0440\u043e\u0448\u0442\u0445\u0438" },
            { "SA", "\u0421\u0430\u0443\u0434\u0438\u0442\u0441\u043a\u0430 \u0410\u0440\u0430\u0431\u0438\u044f" },
            { "pon", "\u043f\u043e\u043d\u0430\u043f\u0435\u0430\u043d" },
            { "Mand", "\u041c\u0430\u043d\u0434\u0430\u0440\u0438\u043d\u0441\u043a\u0430" },
            { "SB", "\u0421\u043e\u043b\u043e\u043c\u043e\u043d\u043e\u0432\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "twq", "\u0442\u0430\u0441\u0430\u0432\u0430\u043a" },
            { "011", "\u0417\u0430\u043f\u0430\u0434\u043d\u0430 \u0410\u0444\u0438\u0440\u043a\u0430" },
            { "SC", "\u0421\u0435\u0439\u0448\u0435\u043b\u0438" },
            { "SD", "\u0421\u0443\u0434\u0430\u043d" },
            { "013", "\u0426\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u0430 \u0410\u043c\u0435\u0440\u0438\u043a\u0430" },
            { "SE", "\u0428\u0432\u0435\u0446\u0438\u044f" },
            { "014", "\u0418\u0437\u0442\u043e\u0447\u043d\u0430 \u0410\u0444\u0440\u0438\u043a\u0430" },
            { "arc", "\u0430\u0440\u0430\u043c\u0435\u0439\u0441\u043a\u0438" },
            { "015", "\u0421\u0435\u0432\u0435\u0440\u043d\u0430 \u0410\u0444\u0440\u0438\u043a\u0430" },
            { "SG", "\u0421\u0438\u043d\u0433\u0430\u043f\u0443\u0440" },
            { "SH", "\u0421\u0432\u0435\u0442\u0430 \u0415\u043b\u0435\u043d\u0430" },
            { "type.lb.strict", "\u0421\u0442\u0440\u043e\u0433 \u0441\u0442\u0438\u043b \u0437\u0430 \u043d\u043e\u0432 \u0440\u0435\u0434" },
            { "017", "\u0426\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u0430 \u0410\u0444\u0440\u0438\u043a\u0430" },
            { "SI", "\u0421\u043b\u043e\u0432\u0435\u043d\u0438\u044f" },
            { "018", "\u042e\u0436\u043d\u043e\u0430\u0444\u0440\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u0440\u0435\u0433\u0438\u043e\u043d" },
            { "SJ", "\u0421\u0432\u0430\u043b\u0431\u0430\u0440\u0434 \u0438 \u042f\u043d \u041c\u0430\u0439\u0435\u043d" },
            { "019", "\u0410\u043c\u0435\u0440\u0438\u043a\u0430" },
            { "SK", "\u0421\u043b\u043e\u0432\u0430\u043a\u0438\u044f" },
            { "SL", "\u0421\u0438\u0435\u0440\u0430 \u041b\u0435\u043e\u043d\u0435" },
            { "SM", "\u0421\u0430\u043d \u041c\u0430\u0440\u0438\u043d\u043e" },
            { "SN", "\u0421\u0435\u043d\u0435\u0433\u0430\u043b" },
            { "SO", "\u0421\u043e\u043c\u0430\u043b\u0438\u044f" },
            { "arn", "\u043c\u0430\u043f\u0443\u0447\u0435" },
            { "arp", "\u0430\u0440\u0430\u043f\u0430\u0445\u043e" },
            { "type.nu.taml", "\u0442\u0440\u0430\u0434\u0438\u0446\u0438\u043e\u043d\u043d\u0438 \u0442\u0430\u043c\u0438\u043b\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "SR", "\u0421\u0443\u0440\u0438\u043d\u0430\u043c" },
            { "SS", "\u042e\u0436\u0435\u043d \u0421\u0443\u0434\u0430\u043d" },
            { "ST", "\u0421\u0430\u043e \u0422\u043e\u043c\u0435 \u0438 \u041f\u0440\u0438\u043d\u0441\u0438\u043f\u0438" },
            { "SV", "\u0421\u0430\u043b\u0432\u0430\u0434\u043e\u0440" },
            { "SX", "\u0421\u0438\u043d\u0442 \u041c\u0430\u0440\u0442\u0435\u043d" },
            { "SY", "\u0421\u0438\u0440\u0438\u044f" },
            { "yao", "\u044f\u043e" },
            { "SZ", "\u0421\u0432\u0430\u0437\u0438\u043b\u0435\u043d\u0434" },
            { "arw", "\u0430\u0440\u0430\u0432\u0430\u043a" },
            { "yap", "\u044f\u043f\u0435\u0437\u0435" },
            { "TA", "\u0422\u0440\u0438\u0441\u0442\u0430\u043d \u0434\u0430 \u041a\u0443\u043d\u044f" },
            { "asa", "\u0430\u0441\u0443" },
            { "type.ms.ussystem", "\u041c\u0435\u0440\u043d\u0430 \u0441\u0438\u0441\u0442\u0435\u043c\u0430 \u043d\u0430 \u0421\u0410\u0429" },
            { "021", "\u0421\u0435\u0432\u0435\u0440\u043d\u0430 \u0410\u043c\u0435\u0440\u0438\u043a\u0430" },
            { "TC", "\u043e\u0441\u0442\u0440\u043e\u0432\u0438 \u0422\u044a\u0440\u043a\u0441 \u0438 \u041a\u0430\u0439\u043a\u043e\u0441" },
            { "yav", "\u044f\u043d\u0433\u0431\u0435\u043d" },
            { "TD", "\u0427\u0430\u0434" },
            { "TF", "\u0424\u0440\u0435\u043d\u0441\u043a\u0438 \u044e\u0436\u043d\u0438 \u0442\u0435\u0440\u0438\u0442\u043e\u0440\u0438\u0438" },
            { "TG", "\u0422\u043e\u0433\u043e" },
            { "TH", "\u0422\u0430\u0439\u043b\u0430\u043d\u0434" },
            { "TJ", "\u0422\u0430\u0434\u0436\u0438\u043a\u0438\u0441\u0442\u0430\u043d" },
            { "029", "\u041a\u0430\u0440\u0438\u0431\u0441\u043a\u0438 \u0440\u0435\u0433\u0438\u043e\u043d" },
            { "TK", "\u0422\u043e\u043a\u0435\u043b\u0430\u0443" },
            { "TL", "\u0418\u0437\u0442\u043e\u0447\u0435\u043d \u0422\u0438\u043c\u043e\u0440" },
            { "ybb", "\u0439\u0435\u043c\u0431\u0430" },
            { "type.co.searchjl", "\u0422\u044a\u0440\u0441\u0435\u043d\u0435 \u043f\u043e \u043f\u044a\u0440\u0432\u043e\u043d\u0430\u0447\u0430\u043b\u043d\u0438 \u0441\u044a\u0433\u043b\u0430\u0441\u043d\u0438 \u0432 \u0445\u0430\u043d\u0433\u0443\u043b" },
            { "TM", "\u0422\u0443\u0440\u043a\u043c\u0435\u043d\u0438\u0441\u0442\u0430\u043d" },
            { "%%BOONT", "\u0411\u0443\u043d\u0442\u043b\u0438\u043d\u0433" },
            { "TN", "\u0422\u0443\u043d\u0438\u0441" },
            { "TO", "\u0422\u043e\u043d\u0433\u0430" },
            { "TR", "\u0422\u0443\u0440\u0446\u0438\u044f" },
            { "TT", "\u0422\u0440\u0438\u043d\u0438\u0434\u0430\u0434 \u0438 \u0422\u043e\u0431\u0430\u0433\u043e" },
            { "TV", "\u0422\u0443\u0432\u0430\u043b\u0443" },
            { "TW", "\u0422\u0430\u0439\u0432\u0430\u043d" },
            { "ast", "\u0430\u0441\u0442\u0443\u0440\u0441\u043a\u0438" },
            { "Orkh", "\u041e\u0440\u0445\u043e\u043d\u043e-\u0435\u043d\u0438\u0441\u0435\u0439\u0441\u043a\u0430" },
            { "TZ", "\u0422\u0430\u043d\u0437\u0430\u043d\u0438\u044f" },
            { "nmg", "\u043a\u0432\u0430\u0441\u0438\u043e" },
            { "Zzzz", "\u043d\u0435\u043f\u043e\u0437\u043d\u0430\u0442\u0430 \u043f\u0438\u0441\u043c\u0435\u043d\u043e\u0441\u0442" },
            { "UA", "\u0423\u043a\u0440\u0430\u0439\u043d\u0430" },
            { "rup", "\u0430\u0440\u0443\u043c\u044a\u043d\u0441\u043a\u0438" },
            { "030", "\u0418\u0437\u0442\u043e\u0447\u043d\u0430 \u0410\u0437\u0438\u044f" },
            { "tyv", "\u0442\u0443\u0432\u0438\u043d\u0441\u043a\u0438" },
            { "sw_CD", "\u043a\u043e\u043d\u0433\u043e\u0430\u043d\u0441\u043a\u0438 \u0441\u0443\u0430\u0445\u0438\u043b\u0438" },
            { "034", "\u042e\u0436\u043d\u0430 \u0410\u0437\u0438\u044f" },
            { "hai", "\u0445\u0430\u0439\u0434\u0430" },
            { "035", "\u042e\u0433\u043e\u0438\u0437\u0442\u043e\u0447\u043d\u0430 \u0410\u0437\u0438\u044f" },
            { "UG", "\u0423\u0433\u0430\u043d\u0434\u0430" },
            { "type.co.pinyin", "\u0421\u043e\u0440\u0442\u0438\u0440\u0430\u043d\u0435 \u041f\u0438\u043d\u0438\u043d" },
            { "039", "\u042e\u0436\u043d\u0430 \u0415\u0432\u0440\u043e\u043f\u0430" },
            { "Sinh", "\u0441\u0438\u043d\u0445\u0430\u043b\u0441\u043a\u0430" },
            { "UM", "\u041e\u0442\u0434\u0430\u043b\u0435\u0447\u0435\u043d\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438 \u043d\u0430 \u0421\u0410\u0429" },
            { "UN", "\u041e\u0440\u0433\u0430\u043d\u0438\u0437\u0430\u0446\u0438\u044f \u043d\u0430 \u043e\u0431\u0435\u0434\u0438\u043d\u0435\u043d\u0438\u0442\u0435 \u043d\u0430\u0446\u0438\u0438" },
            { "US", "\u0421\u044a\u0435\u0434\u0438\u043d\u0435\u043d\u0438 \u0449\u0430\u0442\u0438" },
            { "haw", "\u0445\u0430\u0432\u0430\u0439\u0441\u043a\u0438" },
            { "type.co.gb2312han", "\u041e\u043f\u0440\u043e\u0441\u0442\u0435\u043d \u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438 (GB2312)" },
            { "UY", "\u0423\u0440\u0443\u0433\u0432\u0430\u0439" },
            { "prg", "\u043f\u0440\u0443\u0441\u043a\u0438" },
            { "UZ", "\u0423\u0437\u0431\u0435\u043a\u0438\u0441\u0442\u0430\u043d" },
            { "tzm", "\u0446\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e\u0430\u0442\u043b\u0430\u0441\u043a\u0438 \u0442\u0430\u043c\u0430\u0437\u0438\u0433\u0442" },
            { "type.co.stroke", "\u0421\u043e\u0440\u0442\u0438\u0440\u0430\u043d\u0435 \u043f\u043e \u0449\u0440\u0438\u0445" },
            { "nnh", "\u043d\u0433\u0438\u0435\u043c\u0431\u0443\u043d" },
            { "VA", "\u0412\u0430\u0442\u0438\u043a\u0430\u043d" },
            { "pro", "\u0441\u0442\u0430\u0440\u043e\u043f\u0440\u043e\u0432\u0430\u043d\u0441\u0430\u043b\u0441\u043a\u0438" },
            { "VC", "\u0421\u0435\u0439\u043d\u0442 \u0412\u0438\u043d\u0441\u044a\u043d\u0442 \u0438 \u0413\u0440\u0435\u043d\u0430\u0434\u0438\u043d\u0438" },
            { "VE", "\u0412\u0435\u043d\u0435\u0446\u0443\u0435\u043b\u0430" },
            { "VG", "\u0411\u0440\u0438\u0442\u0430\u043d\u0441\u043a\u0438 \u0412\u0438\u0440\u0434\u0436\u0438\u043d\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "VI", "\u0410\u043c\u0435\u0440\u0438\u043a\u0430\u043d\u0441\u043a\u0438 \u0412\u0438\u0440\u0434\u0436\u0438\u043d\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
            { "VN", "\u0412\u0438\u0435\u0442\u043d\u0430\u043c" },
            { "VU", "\u0412\u0430\u043d\u0443\u0430\u0442\u0443" },
            { "nog", "\u043d\u043e\u0433\u0430\u0438" },
            { "rwk", "\u0440\u0432\u0430" },
            { "non", "\u0441\u0442\u0430\u0440\u043e\u043d\u043e\u0440\u0432\u0435\u0436\u043a\u0438" },
            { "053", "\u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0430\u0437\u0438\u044f" },
            { "%%AREVMDA", "\u0417\u0430\u043f\u0430\u0434\u043d\u043e \u0430\u0440\u043c\u0435\u043d\u0441\u043a\u0438" },
            { "054", "\u041c\u0435\u043b\u0430\u043d\u0435\u0437\u0438\u044f" },
            { "WF", "\u0423\u043e\u043b\u0438\u0441 \u0438 \u0424\u0443\u0442\u0443\u043d\u0430" },
            { "type.co.traditional", "\u0422\u0440\u0430\u0434\u0438\u0446\u0438\u043e\u043d\u043d\u043e" },
            { "057", "\u041c\u0438\u043a\u0440\u043e\u043d\u0435\u0437\u0438\u0439\u0441\u043a\u0438 \u0440\u0435\u0433\u0438\u043e\u043d" },
            { "jgo", "\u043d\u0433\u043e\u043c\u0431\u0430" },
            { "lkt", "\u043b\u0430\u043a\u043e\u0442\u0430" },
            { "type.nu.finance", "\u0424\u0438\u043d\u0430\u043d\u0441\u043e\u0432\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "wae", "\u0432\u0430\u043b\u0437\u0435\u0440\u0441\u043a\u0438 \u043d\u0435\u043c\u0441\u043a\u0438" },
            { "WS", "\u0421\u0430\u043c\u043e\u0430" },
            { "wal", "\u0432\u0430\u043b\u0430\u043c\u043e" },
            { "was", "\u0443\u0430\u0448\u043e" },
            { "war", "\u0432\u0430\u0440\u0430\u0439" },
            { "awa", "\u0430\u0432\u0430\u0434\u0438" },
            { "061", "\u041f\u043e\u043b\u0438\u043d\u0435\u0437\u0438\u044f" },
            { "XK", "\u041a\u043e\u0441\u043e\u0432\u043e" },
            { "Gujr", metaValue_gu },
            { "Zxxx", "\u0431\u0435\u0437 \u043f\u0438\u0441\u043c\u0435\u043d\u043e\u0441\u0442" },
            { "Olck", "\u041e\u043b \u0427\u0438\u043a\u0438" },
            { "wbp", "\u0432\u0430\u043b\u043f\u0438\u0440\u0438" },
            { "Batk", "\u0411\u0430\u0442\u0430\u043a\u0441\u043a\u0430" },
            { "Blis", "\u0411\u043b\u0438\u0441 \u0441\u0438\u043c\u0432\u043e\u043b\u0438" },
            { "YE", "\u0419\u0435\u043c\u0435\u043d" },
            { "nqo", "\u043d\u043a\u043e" },
            { "type.co.standard", "\u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0435\u043d \u0440\u0435\u0434 \u043d\u0430 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u043d\u0435" },
            { "fan", "\u0444\u0430\u043d\u0433" },
            { "%%ROZAJ", "\u0420\u0435\u0437\u0438\u0430\u043d\u0441\u043a\u0438" },
            { "fat", "\u0444\u0430\u043d\u0442\u0438" },
            { "YT", "\u041c\u0430\u0439\u043e\u0442" },
            { "ZA", "\u042e\u0436\u043d\u0430 \u0410\u0444\u0440\u0438\u043a\u0430" },
            { "type.lb.loose", "\u0421\u0432\u043e\u0431\u043e\u0434\u0435\u043d \u0441\u0442\u0438\u043b \u0437\u0430 \u043d\u043e\u0432 \u0440\u0435\u0434" },
            { "Deva", "\u0434\u0435\u0432\u0430\u043d\u0430\u0433\u0430\u0440\u0438" },
            { "type.nu.geor", "\u0433\u0440\u0443\u0437\u0438\u043d\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "Hira", "\u0445\u0438\u0440\u0430\u0433\u0430\u043d\u0430" },
            { "ZM", "\u0417\u0430\u043c\u0431\u0438\u044f" },
            { "%%PINYIN", "\u041f\u0438\u043d\u0438\u043d \u0440\u043e\u043c\u0430\u043d\u0438\u0437\u0430\u0446\u0438\u044f" },
            { "ZW", "\u0417\u0438\u043c\u0431\u0430\u0431\u0432\u0435" },
            { "ZZ", "\u043d\u0435\u043f\u043e\u0437\u043d\u0430\u0442 \u0440\u0435\u0433\u0438\u043e\u043d" },
            { "Runr", "\u0420\u0443\u043d\u0438\u0447\u0435\u0441\u043a\u0430" },
            { "type.ms.metric", "\u041c\u0435\u0442\u0440\u0438\u0447\u043d\u0430 \u0441\u0438\u0441\u0442\u0435\u043c\u0430" },
            { "type.ca.iso8601", "\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u0441\u044a\u0433\u043b\u0430\u0441\u043d\u043e ISO 8601" },
            { "lol", "\u043c\u043e\u043d\u0433\u043e" },
            { "nso", "\u0441\u0435\u0432\u0435\u0440\u0435\u043d \u0441\u043e\u0442\u043e" },
            { "type.nu.telu", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u0442\u0435\u043b\u0443\u0433\u0443" },
            { "loz", "\u043b\u043e\u0437\u0438" },
            { "jmc", "\u043c\u0430\u0447\u0430\u043c\u0435" },
            { "type.nu.hansfin", "\u0444\u0438\u043d\u0430\u043d\u0441\u043e\u0432\u0438 \u0446\u0438\u0444\u0440\u0438 \u0432 \u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438 (\u043e\u043f\u0440\u043e\u0441\u0442\u0435\u043d)" },
            { "hil", "\u0445\u0438\u043b\u0438\u0433\u0430\u0439\u043d\u043e\u043d" },
            { "type.nu.arabext", "\u0440\u0430\u0437\u0448\u0438\u0440\u0435\u043d\u0438 \u0430\u0440\u0430\u0431\u0441\u043a\u043e-\u0438\u043d\u0434\u0438\u0439\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "nus", "\u043d\u0443\u0435\u0440" },
            { "dak", "\u0434\u0430\u043a\u043e\u0442\u0441\u043a\u0438" },
            { "type.nu.fullwide", "\u0446\u0438\u0444\u0440\u0438 \u0441 \u043f\u044a\u043b\u043d\u0430 \u0448\u0438\u0440\u0438\u043d\u0430" },
            { "hit", "\u0445\u0438\u0442\u0441\u043a\u0438" },
            { "dar", "\u0434\u0430\u0440\u0433\u0438\u043d\u0441\u043a\u0438" },
            { "dav", "\u0442\u0430\u0438\u0442\u0430" },
            { "Maya", "\u0419\u0435\u0440\u043e\u0433\u043b\u0438\u0444\u0438 \u043d\u0430 \u041c\u0430\u0438\u0442\u0435" },
            { "lrc", "\u0441\u0435\u0432\u0435\u0440\u0435\u043d \u043b\u0443\u0440\u0438" },
            { "Copt", "\u041a\u043e\u043f\u0442\u0441\u043a\u0430" },
            { "nwc", "\u043a\u043b\u0430\u0441\u0438\u0447\u0435\u0441\u043a\u0438 \u043d\u0435\u0432\u0430\u0440\u0438" },
            { "udm", "\u0443\u0434\u043c\u0443\u0440\u0442\u0441\u043a\u0438" },
            { "Khmr", "\u043a\u0445\u043c\u0435\u0440\u0441\u043a\u0430" },
            { "Limb", "\u041b\u0438\u043c\u0431\u0443" },
            { "sad", "\u0441\u0430\u043d\u0434\u0430\u0432\u0435" },
            { "type.nu.roman", "\u0440\u0438\u043c\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "sah", "\u044f\u043a\u0443\u0442\u0441\u043a\u0438" },
            { "sam", "\u0441\u0430\u043c\u0430\u0440\u0438\u0442\u0430\u043d\u0441\u043a\u0438 \u0430\u0440\u0430\u043c\u0435\u0439\u0441\u043a\u0438" },
            { "%%SCOUSE", "\u041b\u0438\u0432\u044a\u0440\u043f\u0443\u043b\u0441\u043a\u0438 \u0434\u0438\u0430\u043b\u0435\u043a\u0442" },
            { "saq", "\u0441\u0430\u043c\u0431\u0443\u0440\u0443" },
            { "sas", "\u0441\u0430\u0441\u0430\u043a" },
            { "sat", "\u0441\u0430\u043d\u0442\u0430\u043b\u0438" },
            { "jpr", "\u044e\u0434\u0435\u043e-\u043f\u0435\u0440\u0441\u0438\u0439\u0441\u043a\u0438" },
            { "type.d0.npinyin", "\u0426\u0438\u0444\u0440\u043e\u0432\u0438" },
            { "type.nu.native", "\u041c\u0435\u0441\u0442\u043d\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "sba", "\u043d\u0433\u0430\u043c\u0431\u0430\u0439" },
            { "Guru", "\u0433\u0443\u0440\u043c\u0443\u043a\u0445\u0438" },
            { "lua", "\u043b\u0443\u0431\u0430-\u043b\u0443\u043b\u0443\u0430" },
            { "type.d0.fwidth", "\u0421 \u043f\u044a\u043b\u043d\u0430 \u0448\u0438\u0440\u0438\u043d\u0430" },
            { "sbp", "\u0441\u0430\u043d\u0433\u0443" },
            { "lui", "\u043b\u0443\u0438\u0441\u0435\u043d\u044c\u043e" },
            { "nyn", "\u043d\u044f\u043d\u043a\u043e\u043b\u0435" },
            { "nym", "\u043d\u0438\u0430\u043c\u0432\u0435\u0437\u0438" },
            { "lun", "\u043b\u0443\u043d\u0434\u0430" },
            { "nyo", "\u043d\u0443\u043e\u0440\u043e" },
            { "luo", "\u043b\u0443\u043e" },
            { "fil", "\u0444\u0438\u043b\u0438\u043f\u0438\u043d\u0441\u043a\u0438" },
            { "hmn", "\u0445\u043c\u043e\u043d\u0433" },
            { "del", "\u0434\u0435\u043b\u0430\u0443\u0435\u0440" },
            { "lus", "\u043c\u0438\u0437\u043e" },
            { "bal", "\u0431\u0430\u043b\u0443\u0447\u0438" },
            { "den", "\u0441\u043b\u0435\u0439\u0432\u0438" },
            { "ban", "\u0431\u0430\u043b\u0438\u0439\u0441\u043a\u0438" },
            { "uga", "\u0443\u0433\u0430\u0440\u0438\u0442\u0441\u043a\u0438" },
            { "luy", "\u043b\u0443\u0445\u044f" },
            { "bas", "\u0431\u0430\u0441\u0430" },
            { "jrb", "\u044e\u0434\u0435\u043e-\u0430\u0440\u0430\u0431\u0441\u043a\u0438" },
            { "nzi", "\u043d\u0437\u0438\u043c\u0430" },
            { "sco", "\u0448\u043e\u0442\u043b\u0430\u043d\u0434\u0441\u043a\u0438" },
            { "scn", "\u0441\u0438\u0446\u0438\u043b\u0438\u0430\u043d\u0441\u043a\u0438" },
            { "aa", "\u0430\u0444\u0430\u0440\u0441\u043a\u0438" },
            { "ab", "\u0430\u0431\u0445\u0430\u0437\u043a\u0438" },
            { "ae", "\u0430\u0432\u0435\u0441\u0442\u0441\u043a\u0438" },
            { "af", "\u0430\u0444\u0440\u0438\u043a\u0430\u043d\u0441" },
            { "ak", "\u0430\u043a\u0430\u043d" },
            { "am", "\u0430\u043c\u0445\u0430\u0440\u0441\u043a\u0438" },
            { "an", "\u0430\u0440\u0430\u0433\u043e\u043d\u0441\u043a\u0438" },
            { "Arab", "\u0430\u0440\u0430\u0431\u0441\u043a\u0430" },
            { "%%SOLBA", "\u0414\u0438\u0430\u043b\u0435\u043a\u0442 \u0421\u0442\u043e\u043b\u0432\u0438\u0437\u0430" },
            { "Jpan", "\u044f\u043f\u043e\u043d\u0441\u043a\u0430" },
            { "ar", "\u0430\u0440\u0430\u0431\u0441\u043a\u0438" },
            { "Hrkt", "\u044f\u043f\u043e\u043d\u0441\u043a\u0430 \u0441\u0440\u0438\u0447\u043a\u043e\u0432\u0430" },
            { "as", "\u0430\u0441\u0430\u043c\u0441\u043a\u0438" },
            { "Lina", "\u041b\u0438\u043d\u0435\u0439\u043d\u0430 \u0410" },
            { "av", "\u0430\u0432\u0430\u0440\u0441\u043a\u0438" },
            { "Linb", "\u041b\u0438\u043d\u0435\u0439\u043d\u0430 \u0411" },
            { "sdh", "\u044e\u0436\u043d\u043e\u043a\u044e\u0440\u0434\u0441\u043a\u0438" },
            { "ay", "\u0430\u0439\u043c\u0430\u0440\u0430" },
            { "az", "\u0430\u0437\u0435\u0440\u0431\u0430\u0439\u0434\u0436\u0430\u043d\u0441\u043a\u0438" },
            { "%%OSOJS", "\u0414\u0438\u0430\u043b\u0435\u043a\u0442 \u041e\u0441\u0435\u0430\u043a\u043e/\u041e\u0441\u043e\u044f\u043d\u0435" },
            { "ba", "\u0431\u0430\u0448\u043a\u0438\u0440\u0441\u043a\u0438" },
            { "type.co.unihan", "\u0420\u0435\u0434 \u043d\u0430 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u043d\u0435 \u043f\u043e \u043a\u043b\u044e\u0447\u043e\u0432\u0435 \u0438 \u0447\u0435\u0440\u0442\u0438" },
            { "be", "\u0431\u0435\u043b\u0430\u0440\u0443\u0441\u043a\u0438" },
            { "bg", "\u0431\u044a\u043b\u0433\u0430\u0440\u0441\u043a\u0438" },
            { "bi", "\u0431\u0438\u0441\u043b\u0430\u043c\u0430" },
            { "bm", "\u0431\u0430\u043c\u0431\u0430\u0440\u0430" },
            { "bn", "\u0431\u0435\u043d\u0433\u0430\u043b\u0441\u043a\u0438" },
            { "bo", "\u0442\u0438\u0431\u0435\u0442\u0441\u043a\u0438" },
            { "dgr", "\u0434\u043e\u0433\u0440\u0438\u0431" },
            { "br", "\u0431\u0440\u0435\u0442\u043e\u043d\u0441\u043a\u0438" },
            { "bs", "\u0431\u043e\u0441\u043d\u0435\u043d\u0441\u043a\u0438" },
            { "Mymr", "\u0431\u0438\u0440\u043c\u0430\u043d\u0441\u043a\u0430" },
            { "type.nu.laoo", "\u043b\u0430\u043e\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "seh", "\u0441\u0435\u043d\u0430" },
            { "Nkoo", "\u041d\u2019\u041a\u043e" },
            { "sel", "\u0441\u0435\u043b\u043a\u0443\u043f" },
            { "ca", "\u043a\u0430\u0442\u0430\u043b\u043e\u043d\u0441\u043a\u0438" },
            { "ses", "\u043a\u043e\u0439\u0440\u0430\u0431\u043e\u0440\u043e \u0441\u0435\u043d\u0438" },
            { "ce", "\u0447\u0435\u0447\u0435\u043d\u0441\u043a\u0438" },
            { "ch", "\u0447\u0430\u043c\u043e\u0440\u043e" },
            { "%%REVISED", "\u041f\u0440\u043e\u043c\u0435\u043d\u0435\u043d \u043f\u0440\u0430\u0432\u043e\u043f\u0438\u0441" },
            { "co", "\u043a\u043e\u0440\u0441\u0438\u043a\u0430\u043d\u0441\u043a\u0438" },
            { "Orya", metaValue_or },
            { "cr", "\u043a\u0440\u0438\u0438" },
            { "cs", "\u0447\u0435\u0448\u043a\u0438" },
            { "cu", "\u0446\u044a\u0440\u043a\u043e\u0432\u043d\u043e\u0441\u043b\u0430\u0432\u044f\u043d\u0441\u043a\u0438" },
            { "cv", "\u0447\u0443\u0432\u0430\u0448\u043a\u0438" },
            { "cy", "\u0443\u0435\u043b\u0441\u043a\u0438" },
            { "type.nu.ethi", "\u0435\u0442\u0438\u043e\u043f\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "Yiii", "\u0419\u0438" },
            { "da", "\u0434\u0430\u0442\u0441\u043a\u0438" },
            { "de", "\u043d\u0435\u043c\u0441\u043a\u0438" },
            { "type.cf.standard", "\u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0435\u043d \u0444\u043e\u0440\u043c\u0430\u0442 \u043d\u0430 \u0432\u0430\u043b\u0443\u0442\u0430" },
            { "bej", "\u0431\u0435\u044f" },
            { "din", "\u0434\u0438\u043d\u043a\u0430" },
            { "Bugi", "\u0411\u0443\u0433\u0438\u043d\u0441\u043a\u0430" },
            { "bem", "\u0431\u0435\u043c\u0431\u0430" },
            { "sga", "\u0441\u0442\u0430\u0440\u043e\u0438\u0440\u043b\u0430\u043d\u0434\u0441\u043a\u0438" },
            { "type.nu.mong", "\u041c\u043e\u043d\u0433\u043e\u043b\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "dv", "\u0434\u0438\u0432\u0435\u0445\u0438" },
            { "dz", "\u0434\u0437\u043e\u043d\u0433\u043a\u0445\u0430" },
            { "bez", "\u0431\u0435\u043d\u0430" },
            { "type.ca.chinese", "\u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "dje", "\u0437\u0430\u0440\u043c\u0430" },
            { "type.nu.grek", "\u0433\u0440\u044a\u0446\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "ee", "\u0435\u0432\u0435" },
            { "type.lb.normal", "\u041d\u043e\u0440\u043c\u0430\u043b\u0435\u043d \u0441\u0442\u0438\u043b \u0437\u0430 \u043d\u043e\u0432 \u0440\u0435\u0434" },
            { "ro_MD", "\u043c\u043e\u043b\u0434\u043e\u0432\u0441\u043a\u0438" },
            { "el", "\u0433\u0440\u044a\u0446\u043a\u0438" },
            { "en", "\u0430\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438" },
            { "eo", "\u0435\u0441\u043f\u0435\u0440\u0430\u043d\u0442\u043e" },
            { "type.co.big5han", "\u0422\u0440\u0430\u0434\u0438\u0446\u0438\u043e\u043d\u0435\u043d \u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438 (Big5)" },
            { "es", "\u0438\u0441\u043f\u0430\u043d\u0441\u043a\u0438" },
            { "et", "\u0435\u0441\u0442\u043e\u043d\u0441\u043a\u0438" },
            { "Hanb", "\u0445\u0430\u043d\u0431" },
            { "eu", "\u0431\u0430\u0441\u043a\u0438" },
            { "Buhd", "\u0411\u0443\u0445\u0438\u0434" },
            { "Hang", "\u0445\u0430\u043d\u0433\u044a\u043b" },
            { "Samr", "\u0421\u0430\u043c\u0430\u0440\u0438\u0442\u0430\u043d\u0441\u043a\u0430" },
            { "shi", "\u0442\u0430\u0448\u0435\u043b\u0445\u0438\u0442" },
            { "hsb", "\u0433\u043e\u0440\u043d\u043e\u043b\u0443\u0436\u0438\u0448\u043a\u0438" },
            { "Hani", "\u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0430" },
            { "shn", "\u0448\u0430\u043d" },
            { "Hano", "\u0425\u0430\u043d\u0443\u043d\u0443" },
            { "fa", "\u043f\u0435\u0440\u0441\u0438\u0439\u0441\u043a\u0438" },
            { "Hans", "\u043e\u043f\u0440\u043e\u0441\u0442\u0435\u043d\u0430" },
            { "type.nu.latn", "\u0437\u0430\u043f\u0430\u0434\u043d\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "Hant", "\u0442\u0440\u0430\u0434\u0438\u0446\u0438\u043e\u043d\u0435\u043d" },
            { "ff", "\u0444\u0443\u043b\u0430" },
            { "fi", "\u0444\u0438\u043d\u0441\u043a\u0438" },
            { "fj", "\u0444\u0438\u0434\u0436\u0438\u0439\u0441\u043a\u0438" },
            { "fon", "\u0444\u043e\u043d" },
            { "bgn", "\u0437\u0430\u043f\u0430\u0434\u0435\u043d \u0431\u0430\u043b\u043e\u0447\u0438" },
            { "yue", "\u043a\u0430\u043d\u0442\u043e\u043d\u0441\u043a\u0438" },
            { "fo", "\u0444\u0430\u0440\u044c\u043e\u0440\u0441\u043a\u0438" },
            { "type.m0.bgn", "\u0410\u041a\u0413\u041d (BGN)" },
            { "umb", "\u0443\u043c\u0431\u0443\u043d\u0434\u0443" },
            { "fr", "\u0444\u0440\u0435\u043d\u0441\u043a\u0438" },
            { "sid", "\u0441\u0438\u0434\u0430\u043c\u043e" },
            { "fy", "\u0437\u0430\u043f\u0430\u0434\u043d\u043e\u0444\u0440\u0438\u0437\u0438\u0439\u0441\u043a\u0438" },
            { "ga", "\u0438\u0440\u043b\u0430\u043d\u0434\u0441\u043a\u0438" },
            { "gd", "\u0448\u043e\u0442\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u0433\u0430\u043b\u0441\u043a\u0438" },
            { "gl", "\u0433\u0430\u043b\u0438\u0441\u0438\u0439\u0441\u043a\u0438" },
            { "gn", "\u0433\u0443\u0430\u0440\u0430\u043d\u0438" },
            { "bho", "\u0431\u043e\u0434\u0436\u043f\u0443\u0440\u0438" },
            { "und", "\u043d\u0435\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d" },
            { "type.ca.ethiopic-amete-alem", "\u0415\u0442\u0438\u043e\u043f\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u0410\u043c\u0438\u0442 \u0410\u043b\u0435\u043c" },
            { "gu", metaValue_gu },
            { "gv", "\u043c\u0430\u043d\u043a\u0441\u043a\u0438" },
            { "ha", "\u0445\u0430\u0443\u0441\u0430" },
            { "he", metaValue_he },
            { "hi", "\u0445\u0438\u043d\u0434\u0438" },
            { "hup", "\u0445\u0443\u043f\u0430" },
            { "bik", "\u0431\u0438\u043a\u043e\u043b\u0441\u043a\u0438" },
            { "bin", "\u0431\u0438\u043d\u0438" },
            { "ho", "\u0445\u0438\u0440\u0438 \u043c\u043e\u0442\u0443" },
            { "hr", "\u0445\u044a\u0440\u0432\u0430\u0442\u0441\u043a\u0438" },
            { "ht", "\u0445\u0430\u0438\u0442\u044f\u043d\u0441\u043a\u0438 \u043a\u0440\u0435\u043e\u043b\u0441\u043a\u0438" },
            { "hu", "\u0443\u043d\u0433\u0430\u0440\u0441\u043a\u0438" },
            { "hy", "\u0430\u0440\u043c\u0435\u043d\u0441\u043a\u0438" },
            { "hz", "\u0445\u0435\u0440\u0435\u0440\u043e" },
            { "%%FONIPA", "\u041c\u0435\u0436\u0434\u0443\u043d\u0430\u0440\u043e\u0434\u043d\u0430 \u0444\u043e\u043d\u0435\u0442\u0438\u0447\u043d\u0430 \u0430\u0437\u0431\u0443\u043a\u0430" },
            { "ia", "\u0438\u043d\u0442\u0435\u0440\u043b\u0438\u043d\u0433\u0432\u0430" },
            { "Jamo", "\u0434\u0436\u0430\u043c\u043e" },
            { "id", "\u0438\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u0439\u0441\u043a\u0438" },
            { "type.nu.tibt", "\u0442\u0438\u0431\u0435\u0442\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "ie", "\u043e\u043a\u0441\u0438\u0434\u0435\u043d\u0442\u0430\u043b" },
            { "ig", "\u0438\u0433\u0431\u043e" },
            { "ii", "\u0441\u044a\u0447\u0443\u0430\u043d\u0441\u043a\u0438 \u0438" },
            { "frm", "\u0441\u0440\u0435\u0434\u043d\u043e\u0432\u0435\u043a\u043e\u0432\u0435\u043d \u0444\u0440\u0435\u043d\u0441\u043a\u0438" },
            { "ik", "\u0438\u043d\u0443\u043f\u0438\u0430\u043a" },
            { "fro", "\u0441\u0442\u0430\u0440\u043e\u0444\u0440\u0435\u043d\u0441\u043a\u0438" },
            { "io", "\u0438\u0434\u043e" },
            { "frs", "\u0438\u0437\u0442\u043e\u0447\u043d\u043e\u0444\u0440\u0438\u0437\u0438\u0439\u0441\u043a\u0438" },
            { "frr", "\u0441\u0435\u0432\u0435\u0440\u0435\u043d \u0444\u0440\u0438\u0437\u0441\u043a\u0438" },
            { "is", "\u0438\u0441\u043b\u0430\u043d\u0434\u0441\u043a\u0438" },
            { "it", "\u0438\u0442\u0430\u043b\u0438\u0430\u043d\u0441\u043a\u0438" },
            { "iu", "\u0438\u043d\u0443\u043a\u0442\u0438\u0442\u0443\u0442" },
            { "Mlym", metaValue_ml },
            { "ja", "\u044f\u043f\u043e\u043d\u0441\u043a\u0438" },
            { "Sara", "\u0421\u0430\u0440\u0430\u0442\u0438" },
            { "doi", "\u0434\u043e\u0433\u0440\u0438" },
            { "sma", "\u044e\u0436\u043d\u043e\u0441\u0430\u0430\u043c\u0441\u043a\u0438" },
            { "jv", "\u044f\u0432\u0430\u043d\u0441\u043a\u0438" },
            { "mad", "\u043c\u0430\u0434\u0443\u0440\u0441\u043a\u0438" },
            { "smj", "\u043b\u0443\u043b\u0435-\u0441\u0430\u0430\u043c\u0441\u043a\u0438" },
            { "mag", "\u043c\u0430\u0433\u0430\u0445\u0438" },
            { "mai", "\u043c\u0430\u0439\u0442\u0445\u0438\u043b\u0438" },
            { "smn", "\u0438\u043d\u0430\u0440\u0438-\u0441\u0430\u0430\u043c\u0441\u043a\u0438" },
            { "ka", "\u0433\u0440\u0443\u0437\u0438\u043d\u0441\u043a\u0438" },
            { "bla", "\u0441\u0438\u043a\u0441\u0438\u043a\u0430" },
            { "mak", "\u043c\u0430\u043a\u0430\u0441\u0430\u0440" },
            { "sms", "\u0441\u043a\u043e\u043b\u0442-\u0441\u0430\u0430\u043c\u0441\u043a\u0438" },
            { "man", "\u043c\u0430\u043d\u0434\u0438\u043d\u0433\u043e" },
            { "kg", "\u043a\u043e\u043d\u0433\u043e\u0430\u043d\u0441\u043a\u0438" },
            { "Goth", "\u0413\u043e\u0442\u0438\u0447\u0435\u0441\u043a\u0430" },
            { "ki", "\u043a\u0438\u043a\u0443\u044e" },
            { "mas", "\u043c\u0430\u0441\u0430\u0439\u0441\u043a\u0438" },
            { "kj", "\u043a\u0432\u0430\u043d\u044f\u043c\u0430" },
            { "kk", "\u043a\u0430\u0437\u0430\u0445\u0441\u043a\u0438" },
            { "kl", "\u0433\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0441\u043a\u0438" },
            { "km", "\u043a\u0445\u043c\u0435\u0440\u0441\u043a\u0438" },
            { "kn", metaValue_kn },
            { "ko", "\u043a\u043e\u0440\u0435\u0439\u0441\u043a\u0438" },
            { "kr", "\u043a\u0430\u043d\u0443\u0440\u0438" },
            { "ks", "\u043a\u0430\u0448\u043c\u0438\u0440\u0441\u043a\u0438" },
            { "Cirt", "\u041a\u0438\u0440\u0442" },
            { "Lepc", "\u041b\u0435\u043f\u0447\u0430" },
            { "Avst", "\u0410\u0432\u0435\u0441\u0442\u0430\u043d\u0441\u043a\u0430" },
            { "ku", "\u043a\u044e\u0440\u0434\u0441\u043a\u0438" },
            { "kv", "\u043a\u043e\u043c\u0438" },
            { "kw", "\u043a\u043e\u0440\u043d\u0443\u043e\u043b\u0441\u043a\u0438" },
            { "ky", "\u043a\u0438\u0440\u0433\u0438\u0437\u043a\u0438" },
            { "snk", "\u0441\u043e\u043d\u0438\u043d\u043a\u0435" },
            { "la", "\u043b\u0430\u0442\u0438\u043d\u0441\u043a\u0438" },
            { "lb", "\u043b\u044e\u043a\u0441\u0435\u043c\u0431\u0443\u0440\u0433\u0441\u043a\u0438" },
            { "type.nu.mlym", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u043c\u0430\u043b\u0430\u044f\u043b\u0430\u043c" },
            { "lg", "\u0433\u0430\u043d\u0434\u0430" },
            { "Roro", "\u0420\u043e\u043d\u0433\u043e-\u0440\u043e\u043d\u0433\u043e" },
            { "li", "\u043b\u0438\u043c\u0431\u0443\u0440\u0433\u0441\u043a\u0438" },
            { "Tibt", "\u0442\u0438\u0431\u0435\u0442\u0441\u043a\u0430" },
            { "ln", "\u043b\u0438\u043d\u0433\u0430\u043b\u0430" },
            { "fur", "\u0444\u0440\u0438\u0443\u043b\u0438\u0430\u043d\u0441\u043a\u0438" },
            { "lo", "\u043b\u0430\u043e\u0441\u043a\u0438" },
            { "type.ms.uksystem", "\u0418\u043c\u043f\u0435\u0440\u0441\u043a\u0430 \u043c\u0435\u0440\u043d\u0430 \u0441\u0438\u0441\u0442\u0435\u043c\u0430" },
            { "lt", "\u043b\u0438\u0442\u043e\u0432\u0441\u043a\u0438" },
            { "lu", "\u043b\u0443\u0431\u0430-\u043a\u0430\u0442\u0430\u043d\u0433\u0430" },
            { "lv", "\u043b\u0430\u0442\u0432\u0438\u0439\u0441\u043a\u0438" },
            { "sog", "\u0441\u043e\u0433\u0434\u0438\u0439\u0441\u043a\u0438" },
            { "mg", "\u043c\u0430\u043b\u0433\u0430\u0448\u043a\u0438" },
            { "mh", "\u043c\u0430\u0440\u0448\u0430\u043b\u0435\u0437\u0435" },
            { "type.co.ducet", "\u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0435\u043d \u0440\u0435\u0434 \u043d\u0430 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u043d\u0435 \u0432 \u0423\u043d\u0438\u043a\u043e\u0434" },
            { "mi", "\u043c\u0430\u043e\u0440\u0441\u043a\u0438" },
            { "mk", "\u043c\u0430\u043a\u0435\u0434\u043e\u043d\u0441\u043a\u0438" },
            { "ml", metaValue_ml },
            { "mn", "\u043c\u043e\u043d\u0433\u043e\u043b\u0441\u043a\u0438" },
            { "mr", "\u043c\u0430\u0440\u0430\u0442\u0438" },
            { "ms", "\u043c\u0430\u043b\u0430\u0439\u0441\u043a\u0438" },
            { "mt", "\u043c\u0430\u043b\u0442\u0438\u0439\u0441\u043a\u0438" },
            { "my", "\u0431\u0438\u0440\u043c\u0430\u043d\u0441\u043a\u0438" },
            { "Saur", "\u0421\u0430\u0443\u0440\u0430\u0448\u0442\u0440\u0430" },
            { "Armn", "\u0430\u0440\u043c\u0435\u043d\u0441\u043a\u0430" },
            { "mdf", "\u043c\u043e\u043a\u0448\u0430" },
            { "dsb", "\u0434\u043e\u043b\u043d\u043e\u043b\u0443\u0436\u0438\u0448\u043a\u0438" },
            { "Armi", "\u0410\u0440\u0430\u043c\u0435\u0439\u0441\u043a\u0430" },
            { "na", "\u043d\u0430\u0443\u0440\u0443" },
            { "type.co.search", "\u0442\u044a\u0440\u0441\u0435\u043d\u0435 \u0441 \u043e\u0431\u0449\u043e \u043f\u0440\u0435\u0434\u043d\u0430\u0437\u043d\u0430\u0447\u0435\u043d\u0438\u0435" },
            { "nb", "\u043d\u043e\u0440\u0432\u0435\u0436\u043a\u0438 (\u0431\u0443\u043a\u043c\u043e\u043b)" },
            { "nd", "\u0441\u0435\u0432\u0435\u0440\u0435\u043d \u043d\u0434\u0435\u0431\u0435\u043b\u0435" },
            { "ne", "\u043d\u0435\u043f\u0430\u043b\u0441\u043a\u0438" },
            { "ng", "\u043d\u0434\u043e\u043d\u0433\u0430" },
            { "mdr", "\u043c\u0430\u043d\u0434\u0430\u0440" },
            { "nl", "\u043d\u0438\u0434\u0435\u0440\u043b\u0430\u043d\u0434\u0441\u043a\u0438" },
            { "nn", "\u043d\u043e\u0440\u0432\u0435\u0436\u043a\u0438 (\u043d\u044e\u043d\u043e\u0448\u043a)" },
            { "no", "\u043d\u043e\u0440\u0432\u0435\u0436\u043a\u0438" },
            { "nr", "\u044e\u0436\u0435\u043d \u043d\u0434\u0435\u0431\u0435\u043b\u0435" },
            { "nv", "\u043d\u0430\u0432\u0430\u0445\u043e" },
            { "kaa", "\u043a\u0430\u0440\u0430\u043a\u0430\u043b\u043f\u0430\u0448\u043a\u0438" },
            { "ny", "\u043d\u044f\u043d\u0434\u0436\u0430" },
            { "kac", "\u043a\u0430\u0447\u0438\u043d\u0441\u043a\u0438" },
            { "kab", "\u043a\u0430\u0431\u0438\u043b\u0441\u043a\u0438" },
            { "%%POLYTON", "\u041f\u043e\u043b\u0438\u0442\u043e\u043d\u0438\u0447\u043d\u043e" },
            { "oc", "\u043e\u043a\u0441\u0438\u0442\u0430\u043d\u0441\u043a\u0438" },
            { "kaj", "\u0436\u0436\u0443" },
            { "kam", "\u043a\u0430\u043c\u0431\u0430" },
            { "men", "\u043c\u0435\u043d\u0434\u0435" },
            { "oj", "\u043e\u0434\u0436\u0438\u0431\u0432\u0430" },
            { "mer", "\u043c\u0435\u0440\u0443" },
            { "type.nu.armn", "\u0430\u0440\u043c\u0435\u043d\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "om", "\u043e\u0440\u043e\u043c\u043e" },
            { "kaw", "\u043a\u0430\u0432\u0438" },
            { "or", metaValue_or },
            { "os", "\u043e\u0441\u0435\u0442\u0441\u043a\u0438" },
            { "kbd", "\u043a\u0430\u0431\u0430\u0440\u0434\u0438\u0430\u043d" },
            { "mfe", "\u043c\u043e\u0440\u0438\u0441\u0438\u0435\u043d" },
            { "srn", "\u0441\u0440\u0430\u043d\u0430\u043d \u0442\u043e\u043d\u0433\u043e" },
            { "pa", "\u043f\u0435\u043d\u0434\u0436\u0430\u0431\u0441\u043a\u0438" },
            { "dua", "\u0434\u0443\u0430\u043b\u0430" },
            { "srr", "\u0441\u0435\u0440\u0435\u0440" },
            { "%%LIPAW", "\u0414\u0438\u0430\u043b\u0435\u043a\u0442 \u041b\u0438\u043f\u043e\u0432\u0430\u0446" },
            { "pi", "\u043f\u0430\u043b\u0438" },
            { "pl", "\u043f\u043e\u043b\u0441\u043a\u0438" },
            { "dum", "\u0441\u0440\u0435\u0434\u043d\u043e\u0432\u0435\u043a\u043e\u0432\u0435\u043d \u0445\u043e\u043b\u0430\u043d\u0434\u0441\u043a\u0438" },
            { "type.ca.dangi", "\u043a\u043e\u0440\u0435\u0439\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "ps", "\u043f\u0443\u0449\u0443" },
            { "pt", "\u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u0441\u043a\u0438" },
            { "mga", "\u0441\u0440\u0435\u0434\u043d\u043e\u0432\u0435\u043a\u043e\u0432\u0435\u043d \u0438\u0440\u043b\u0430\u043d\u0434\u0441\u043a\u0438" },
            { "key.co", "\u0440\u0435\u0434 \u043d\u0430 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u043d\u0435" },
            { "kcg", "\u0442\u0443\u0430\u043f" },
            { "mgh", "\u043c\u0430\u043a\u0443\u0430 \u043c\u0435\u0442\u043e" },
            { "key.cf", "\u0444\u043e\u0440\u043c\u0430\u0442 \u043d\u0430 \u0432\u0430\u043b\u0443\u0442\u0430" },
            { "bra", "\u0431\u0440\u0430\u0434\u0436" },
            { "key.ca", "\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "Laoo", "\u043b\u0430\u043e\u0441\u043a\u0430" },
            { "mgo", "\u043c\u0435\u0442\u0430" },
            { "type.hc.h23", "24-\u0447\u0430\u0441\u043e\u0432\u0430 \u0441\u0438\u0441\u0442\u0435\u043c\u0430 (0 \u2013 23)" },
            { "type.hc.h24", "24-\u0447\u0430\u0441\u043e\u0432\u0430 \u0441\u0438\u0441\u0442\u0435\u043c\u0430 (1 \u2013 24)" },
            { "ssy", "\u0441\u0430\u0445\u043e" },
            { "type.nu.mymr", "\u0431\u0438\u0440\u043c\u0430\u043d\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "qu", "\u043a\u0435\u0447\u0443\u0430" },
            { "zap", "\u0437\u0430\u043f\u043e\u0442\u0435\u043a" },
            { "brx", "\u0431\u043e\u0434\u043e" },
            { "Lana", "\u041b\u0430\u043d\u043d\u0430" },
            { "kde", "\u043c\u0430\u043a\u043e\u043d\u0434\u0435" },
            { "Ethi", "\u0435\u0442\u0438\u043e\u043f\u0441\u043a\u0430" },
            { "type.hc.h12", "12-\u0447\u0430\u0441\u043e\u0432\u0430 \u0441\u0438\u0441\u0442\u0435\u043c\u0430 (1 \u2013 12)" },
            { "type.hc.h11", "12-\u0447\u0430\u0441\u043e\u0432\u0430 \u0441\u0438\u0441\u0442\u0435\u043c\u0430 (0 \u2013 11)" },
            { "rm", "\u0440\u0435\u0442\u043e\u0440\u043e\u043c\u0430\u043d\u0441\u043a\u0438" },
            { "rn", "\u0440\u0443\u043d\u0434\u0438" },
            { "key.cu", "\u0432\u0430\u043b\u0443\u0442\u0430" },
            { "ro", "\u0440\u0443\u043c\u044a\u043d\u0441\u043a\u0438" },
            { "%%SAAHO", "\u0421\u0430\u0445\u043e" },
            { "type.nu.orya", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u043e\u0440\u0438\u044f" },
            { "type.nu.hanidec", "\u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438 \u0434\u0435\u0441\u0435\u0442\u0438\u0447\u043d\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "ru", "\u0440\u0443\u0441\u043a\u0438" },
            { "rw", "\u043a\u0438\u043d\u044f\u0440\u0443\u0430\u043d\u0434\u0430" },
            { "zbl", "\u0431\u043b\u0438\u0441 \u0441\u0438\u043c\u0432\u043e\u043b\u0438" },
            { "kea", "\u043a\u0430\u0431\u043e\u0432\u0435\u0440\u0434\u0438\u0430\u043d\u0441\u043a\u0438" },
            { "mic", "\u043c\u0438\u043a\u043c\u0430\u043a" },
            { "suk", "\u0441\u0443\u043a\u0443\u043c\u0430" },
            { "sa", "\u0441\u0430\u043d\u0441\u043a\u0440\u0438\u0442" },
            { "sc", "\u0441\u0430\u0440\u0434\u0438\u043d\u0441\u043a\u0438" },
            { "sus", "\u0441\u0443\u0441\u0443" },
            { "sd", "\u0441\u0438\u043d\u0434\u0445\u0438" },
            { "se", "\u0441\u0435\u0432\u0435\u0440\u043d\u043e\u0441\u0430\u0430\u043c\u0441\u043a\u0438" },
            { "min", "\u043c\u0438\u043d\u0430\u043d\u0433\u043a\u0430\u0431\u0430\u0443" },
            { "sg", "\u0441\u0430\u043d\u0433\u043e" },
            { "sh", "\u0441\u044a\u0440\u0431\u043e\u0445\u044a\u0440\u0432\u0430\u0442\u0441\u043a\u0438" },
            { "si", "\u0441\u0438\u043d\u0445\u0430\u043b\u0441\u043a\u0438" },
            { "sux", "\u0448\u0443\u043c\u0435\u0440\u0441\u043a\u0438" },
            { "sk", "\u0441\u043b\u043e\u0432\u0430\u0448\u043a\u0438" },
            { "sl", "\u0441\u043b\u043e\u0432\u0435\u043d\u0441\u043a\u0438" },
            { "sm", "\u0441\u0430\u043c\u043e\u0430\u043d\u0441\u043a\u0438" },
            { "sn", "\u0448\u043e\u043d\u0430" },
            { "so", "\u0441\u043e\u043c\u0430\u043b\u0438\u0439\u0441\u043a\u0438" },
            { "type.nu.arab", "\u0430\u0440\u0430\u0431\u0441\u043a\u043e-\u0438\u043d\u0434\u0438\u0439\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "sq", "\u0430\u043b\u0431\u0430\u043d\u0441\u043a\u0438" },
            { "sr", "\u0441\u0440\u044a\u0431\u0441\u043a\u0438" },
            { "ss", "\u0441\u0432\u0430\u0442\u0438" },
            { "type.cf.account", "\u0444\u043e\u0440\u043c\u0430\u0442 \u043d\u0430 \u0432\u0430\u043b\u0443\u0442\u0430 \u0437\u0430 \u0441\u0447\u0435\u0442\u043e\u0432\u043e\u0434\u043d\u0438 \u0446\u0435\u043b\u0438" },
            { "st", "\u0441\u0435\u0441\u043e\u0442\u043e" },
            { "Java", "\u042f\u0432\u0430\u043d\u0441\u043a\u0430" },
            { "su", "\u0441\u0443\u043d\u0434\u0430\u043d\u0441\u043a\u0438" },
            { "%%NEDIS", "\u0414\u0438\u0430\u043b\u0435\u043a\u0442 \u041d\u0430\u0442\u0438\u0441\u043e\u043d\u0435" },
            { "sv", "\u0448\u0432\u0435\u0434\u0441\u043a\u0438" },
            { "sw", "\u0441\u0443\u0430\u0445\u0438\u043b\u0438" },
            { "type.nu.hantfin", "\u0444\u0438\u043d\u0430\u043d\u0441\u043e\u0432\u0438 \u0446\u0438\u0444\u0440\u0438 \u0432 \u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438 (\u0442\u0440\u0430\u0434\u0438\u0446\u0438\u043e\u043d\u0435\u043d)" },
            { "ibb", "\u0438\u0431\u0438\u0431\u0438\u043e" },
            { "iba", "\u0438\u0431\u0430\u043d" },
            { "ta", "\u0442\u0430\u043c\u0438\u043b\u0441\u043a\u0438" },
            { "142", "\u0410\u0437\u0438\u044f" },
            { "bua", "\u0431\u0443\u0440\u044f\u0442\u0441\u043a\u0438" },
            { "143", "\u0426\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u0430 \u0410\u0437\u0438\u044f" },
            { "te", metaValue_te },
            { "145", "\u0417\u0430\u043f\u0430\u0434\u043d\u0430 \u0410\u0437\u0438\u044f" },
            { "tg", "\u0442\u0430\u0434\u0436\u0438\u043a\u0441\u043a\u0438" },
            { "th", "\u0442\u0430\u0439\u0441\u043a\u0438" },
            { "ti", "\u0442\u0438\u0433\u0440\u0438\u043d\u044f" },
            { "bug", "\u0431\u0443\u0433\u0438\u043d\u0441\u043a\u0438" },
            { "kfo", "\u043a\u043e\u0440\u043e" },
            { "tk", "\u0442\u0443\u0440\u043a\u043c\u0435\u043d\u0441\u043a\u0438" },
            { "tl", "\u0442\u0430\u0433\u0430\u043b\u043e\u0433" },
            { "tn", "\u0442\u0441\u0432\u0430\u043d\u0430" },
            { "to", "\u0442\u043e\u043d\u0433\u0430\u043d\u0441\u043a\u0438" },
            { "dyo", "\u0434\u0438\u043e\u043b\u0430-\u0444\u043e\u043d\u0438" },
            { "type.nu.jpan", "\u044f\u043f\u043e\u043d\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "tr", "\u0442\u0443\u0440\u0441\u043a\u0438" },
            { "ts", "\u0446\u043e\u043d\u0433\u0430" },
            { "swb", "\u043a\u043e\u043c\u043e\u0440\u0441\u043a\u0438" },
            { "Cakm", "\u0427\u0430\u043a\u043c\u0430" },
            { "tt", "\u0442\u0430\u0442\u0430\u0440\u0441\u043a\u0438" },
            { "dyu", "\u0434\u0438\u0443\u043b\u0430" },
            { "tw", "\u0442\u0443\u0438" },
            { "ty", "\u0442\u0430\u0438\u0442\u044f\u043d\u0441\u043a\u0438" },
            { "%%BISKE", "\u0414\u0438\u0430\u043b\u0435\u043a\u0442 \u0421\u0430\u043d \u0414\u0436\u043e\u0440\u0434\u0436\u0438\u043e/\u0411\u0438\u043b\u0430" },
            { "150", "\u0415\u0432\u0440\u043e\u043f\u0430" },
            { "151", "\u0418\u0437\u0442\u043e\u0447\u043d\u0430 \u0415\u0432\u0440\u043e\u043f\u0430" },
            { "154", "\u0421\u0435\u0432\u0435\u0440\u043d\u0430 \u0415\u0432\u0440\u043e\u043f\u0430" },
            { "dzg", "\u0434\u0430\u0437\u0430\u0433\u0430" },
            { "155", "\u0417\u0430\u043f\u0430\u0434\u043d\u0430 \u0415\u0432\u0440\u043e\u043f\u0430" },
            { "ug", "\u0443\u0439\u0433\u0443\u0440\u0441\u043a\u0438" },
            { "Ital", "\u0414\u0440\u0435\u0432\u043d\u043e \u0438\u0442\u0430\u043b\u0438\u0439\u0441\u043a\u0430" },
            { "Kore", "\u043a\u043e\u0440\u0435\u0439\u0441\u043a\u0430" },
            { "Zyyy", "\u043e\u0431\u0449\u0430" },
            { "uk", "\u0443\u043a\u0440\u0430\u0438\u043d\u0441\u043a\u0438" },
            { "type.ca.coptic", "\u041a\u043e\u043f\u0442\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
            { "ur", "\u0443\u0440\u0434\u0443" },
            { "%%1994", "\u0421\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0435\u043d \u0440\u0435\u0437\u0438\u0430\u043d\u0441\u043a\u0438 \u043f\u0440\u0430\u0432\u043e\u043f\u0438\u0441" },
            { "xal", "\u043a\u0430\u043b\u043c\u0438\u043a" },
            { "zen", "\u0437\u0435\u043d\u0430\u0433\u0430" },
            { "uz", "\u0443\u0437\u0431\u0435\u043a\u0441\u043a\u0438" },
            { "kha", "\u043a\u0445\u0430\u0441\u0438" },
            { "%%1996", "\u041d\u0435\u043c\u0441\u043a\u0438 \u043f\u0440\u0430\u0432\u043e\u043f\u0438\u0441 \u043e\u0442 1996" },
            { "nds_NL", "\u0434\u043e\u043b\u043d\u043e\u0441\u0430\u043a\u0441\u043e\u043d\u0441\u043a\u0438" },
            { "Sylo", "\u0421\u0438\u043b\u043e\u0442\u0438 \u041d\u0430\u0433\u0440\u0438" },
            { "ve", "\u0432\u0435\u043d\u0434\u0430" },
            { "type.ca.roc", "\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u043d\u0430 \u0420\u0435\u043f\u0443\u0431\u043b\u0438\u043a\u0430 \u041a\u0438\u0442\u0430\u0439" },
            { "vi", "\u0432\u0438\u0435\u0442\u043d\u0430\u043c\u0441\u043a\u0438" },
            { "kho", "\u043a\u043e\u0442\u0441\u043a\u0438" },
            { "khq", "\u043a\u043e\u0439\u0440\u0430 \u0447\u0438\u0438\u043d\u0438" },
            { "key.hc", "\u0427\u0430\u0441\u043e\u0432\u0438 \u0444\u043e\u0440\u043c\u0430\u0442 (12- \u0438\u043b\u0438 24-\u0447\u0430\u0441\u043e\u0432)" },
            { "%%TARASK", "\u0422\u0430\u0440\u0430\u0448\u043a\u0435\u0432\u0438\u0446\u0430" },
            { "vo", "\u0432\u043e\u043b\u0430\u043f\u044e\u043a" },
            { "syc", "\u043a\u043b\u0430\u0441\u0438\u0447\u0435\u0441\u043a\u0438 \u0441\u0438\u0440\u0438\u0439\u0441\u043a\u0438" },
            { "Osma", "\u041e\u0441\u043c\u0430\u043d\u0441\u043a\u0430" },
            { "quc", "\u043a\u0438\u0447\u0435" },
            { "gaa", "\u0433\u0430" },
            { "wa", "\u0432\u0430\u043b\u043e\u043d\u0441\u043a\u0438" },
            { "gag", "\u0433\u0430\u0433\u0430\u0443\u0437\u043a\u0438" },
            { "syr", "\u0441\u0438\u0440\u0438\u0439\u0441\u043a\u0438" },
            { "Grek", "\u0433\u0440\u044a\u0446\u043a\u0430" },
            { "Lydi", "\u041b\u0438\u0434\u0438\u0439\u0441\u043a\u0430" },
            { "Xsux", "\u0428\u0443\u043c\u0435\u0440\u043e-\u0430\u043a\u0430\u0434\u0441\u043a\u0438 \u043a\u043b\u0438\u043d\u043e\u043f\u0438\u0441" },
            { "wo", "\u0432\u043e\u043b\u043e\u0444" },
            { "zgh", "\u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0435\u043d \u043c\u0430\u0440\u043e\u043a\u0430\u043d\u0441\u043a\u0438 \u0442\u0430\u043c\u0430\u0437\u0438\u0433\u0442" },
            { "ar_001", "\u0441\u044a\u0432\u0440\u0435\u043c\u0435\u043d\u0435\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0435\u043d \u0430\u0440\u0430\u0431\u0441\u043a\u0438" },
            { "Cans", "\u0423\u043d\u0438\u0444\u0438\u0446\u0438\u0440\u0430\u043d\u0438 \u0441\u0438\u043c\u0432\u043e\u043b\u0438 \u043d\u0430 \u043a\u0430\u043d\u0430\u0434\u0441\u043a\u0438 \u0430\u0431\u043e\u0440\u0438\u0433\u0435\u043d\u0438" },
            { "gay", "\u0433\u0430\u0439\u043e" },
            { "Mong", "\u043c\u043e\u043d\u0433\u043e\u043b\u0441\u043a\u0430" },
            { "mnc", "\u043c\u0430\u043d\u0434\u0436\u0443\u0440\u0441\u043a\u0438" },
            { "Latf", "\u041b\u0430\u0442\u0438\u043d\u0441\u043a\u0430 \u0444\u0440\u0430\u043a\u0442\u0443\u0440\u0430" },
            { "gba", "\u0433\u0431\u0430\u044f" },
            { "mni", "\u043c\u0430\u043d\u0438\u043f\u0443\u0440\u0441\u043a\u0438" },
            { "Latn", "\u043b\u0430\u0442\u0438\u043d\u0438\u0446\u0430" },
            { "Latg", "\u0413\u0430\u043b\u0441\u043a\u0430 \u043b\u0430\u0442\u0438\u043d\u0441\u043a\u0430" },
            { "type.nu.hans", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438 (\u043e\u043f\u0440\u043e\u0441\u0442\u0435\u043d)" },
            { "type.nu.hant", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438 (\u0442\u0440\u0430\u0434\u0438\u0446\u0438\u043e\u043d\u0435\u043d)" },
            { "xh", "\u043a\u0441\u043e\u0441\u0430" },
            { "type.nu.romanlow", "\u0440\u0438\u043c\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438 \u0432 \u0434\u043e\u043b\u0435\u043d \u0440\u0435\u0433\u0438\u0441\u0442\u044a\u0440" },
            { "byn", "\u0431\u0438\u043b\u0435\u043d\u0441\u043a\u0438" },
            { "Lyci", "\u041b\u0438\u0446\u0438\u0439\u0441\u043a\u0430" },
            { "osa", "\u043e\u0441\u0435\u0439\u0434\u0436\u0438" },
            { "Moon", "\u041c\u0443\u043d" },
            { "moh", "\u043c\u043e\u0445\u043e\u0443\u043a" },
            { "kkj", "\u043a\u0430\u043a\u043e" },
            { "%%1694ACAD", "\u0420\u0430\u043d\u0435\u043d \u0441\u044a\u0432\u0440\u0435\u043c\u0435\u043d\u0435\u043d \u0444\u0440\u0435\u043d\u0441\u043a\u0438" },
            { "yi", "\u0438\u0434\u0438\u0448" },
            { "mos", "\u043c\u043e\u0441\u0438" },
            { "Syrc", "\u0421\u0438\u0440\u0438\u0439\u0441\u043a\u0430" },
            { "Dsrt", "\u0414\u0435\u0437\u0435\u0440\u0435\u0442" },
            { "yo", "\u0439\u043e\u0440\u0443\u0431\u0430" },
            { "type.nu.traditional", "\u0422\u0440\u0430\u0434\u0438\u0446\u0438\u043e\u043d\u043d\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "Syrj", "\u0417\u0430\u043f\u0430\u0434\u043d\u0430 \u0441\u0438\u0440\u0438\u0439\u0441\u043a\u0430" },
            { "ota", "\u043e\u0442\u043e\u043c\u0430\u043d\u0441\u043a\u0438 \u0442\u0443\u0440\u0441\u043a\u0438" },
            { "Syre", "\u0421\u0438\u0440\u0438\u0439\u0441\u043a\u0430 \u0435\u0441\u0442\u0440\u0430\u043d\u0433\u0435\u043b\u043e" },
            { "vai", "\u0432\u0430\u0438" },
            { "za", "\u0437\u0443\u0430\u043d\u0433" },
            { "Cari", "\u041a\u0430\u0440\u0438\u0439\u0441\u043a\u0430" },
            { "kln", "\u043a\u0430\u043b\u0435\u043d\u0434\u0436\u0438\u043d" },
            { "zh", "\u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438" },
            { "Bopo", "\u0431\u043e\u043f\u043e\u043c\u043e\u0444\u043e" },
            { "Perm", "\u0414\u0440\u0435\u0432\u043d\u043e \u043f\u0435\u0440\u043c\u0441\u043a\u0430" },
            { "key.lb", "\u0421\u0442\u0438\u043b \u0437\u0430 \u043d\u043e\u0432 \u0440\u0435\u0434" },
            { "zu", "\u0437\u0443\u043b\u0443\u0441\u043a\u0438" },
            { "type.co.phonebook", "\u0410\u0437\u0431\u0443\u0447\u0435\u043d \u0440\u0435\u0434" },
            { "%%MONOTON", "\u041c\u043e\u043d\u043e\u0442\u043e\u043d\u0438\u0447\u043d\u043e" },
            { "Geor", "\u0433\u0440\u0443\u0437\u0438\u043d\u0441\u043a\u0430" },
            { "kmb", "\u043a\u0438\u043c\u0431\u0443\u043d\u0434\u0443" },
            { "type.nu.jpanfin", "\u044f\u043f\u043e\u043d\u0441\u043a\u0438 \u0444\u0438\u043d\u0430\u043d\u0441\u043e\u0432\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "Cham", "\u0425\u0430\u043c\u0438\u0442\u0441\u043a\u0430" },
            { "gez", "\u0433\u0438\u0438\u0437" },
            { "Syrn", "\u0418\u0437\u0442\u043e\u0447\u043d\u0430 \u0441\u0438\u0440\u0438\u0439\u0441\u043a\u0430" },
            { "type.co.reformed", "\u0421\u043b\u0435\u0434\u0440\u0435\u0444\u043e\u0440\u043c\u0435\u043d \u0440\u0435\u0434 \u043d\u0430 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u043d\u0435" },
            { "Tglg", "\u0422\u0430\u0433\u0430\u043b\u043e\u0433" },
            { "Egyd", "\u0415\u0433\u0438\u043f\u0435\u0442\u0441\u043a\u043e \u0434\u0435\u043c\u043e\u0442\u0438\u0447\u043d\u043e \u043f\u0438\u0441\u043c\u043e" },
            { "Egyh", "\u0415\u0433\u0438\u043f\u0435\u0442\u0441\u043a\u043e \u0439\u0435\u0440\u0430\u0442\u0438\u0447\u043d\u043e \u043f\u0438\u0441\u043c\u043e" },
            { "ebu", "\u0435\u043c\u0431\u0443" },
            { "Egyp", "\u0415\u0433\u0438\u043f\u0435\u0442\u0441\u043a\u0438 \u0439\u0435\u0440\u043e\u0433\u043b\u0438\u0444\u0438" },
            { "Geok", "\u0413\u0440\u0443\u0437\u0438\u043d\u0441\u043a\u0430 \u0445\u0443\u0446\u0443\u0440\u0438" },
            { "zh_Hans", "\u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438 (\u043e\u043f\u0440\u043e\u0441\u0442\u0435\u043d)" },
            { "koi", "\u043a\u043e\u043c\u0438-\u043f\u0435\u0440\u043c\u044f\u043a\u0441\u043a\u0438" },
            { "Hung", "\u0421\u0442\u0430\u0440\u043e\u0443\u043d\u0433\u0430\u0440\u0441\u043a\u0430" },
            { "kok", "\u043a\u043e\u043d\u043a\u0430\u043d\u0438" },
            { "%%1901", "\u0422\u0440\u0430\u0434\u0438\u0446\u0438\u043e\u043d\u0435\u043d \u043d\u0435\u043c\u0441\u043a\u0438 \u043f\u0440\u0430\u0432\u043e\u043f\u0438\u0441" },
            { "kos", "\u043a\u043e\u0441\u0440\u0430\u0435\u043d" },
            { "Sund", "\u0421\u0443\u043d\u0434\u0430\u043d\u0441\u043a\u0430" },
            { "kpe", "\u043a\u043f\u0435\u043b\u0435" },
            { "type.nu.khmr", "\u043a\u0445\u043c\u0435\u0440\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "ilo", "\u0438\u043b\u043e\u043a\u043e" },
            { "%%VALENCIA", "\u0412\u0430\u043b\u0435\u043d\u0441\u0438\u0430\u043d\u0441\u043a\u0438" },
            { "Cprt", "\u041a\u0438\u043f\u044a\u0440\u0441\u043a\u0430" },
            { "%%BAKU1926", "\u0423\u043d\u0438\u0444\u0438\u0446\u0438\u0440\u0430\u043d\u0430 \u0442\u044e\u0440\u043a\u0441\u043a\u0430 \u0430\u0437\u0431\u0443\u043a\u0430" },
            { "mua", "\u043c\u0443\u043d\u0434\u0430\u043d\u0433" },
            { "type.nu.guru", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u0433\u0443\u0440\u043c\u0443\u043a\u0445\u0438" },
            { "mul", "\u043c\u043d\u043e\u0433\u043e\u0435\u0437\u0438\u0447\u043d\u0438" },
            { "cad", "\u043a\u0430\u0434\u0434\u043e" },
            { "key.ms", "\u041c\u0435\u0440\u043d\u0430 \u0441\u0438\u0441\u0442\u0435\u043c\u0430" },
            { "mus", "\u043c\u0443\u0441\u043a\u043e\u0433\u0441\u043a\u0438" },
            { "Glag", "\u0413\u043b\u0430\u0433\u043e\u043b\u0438\u0447\u0435\u0441\u043a\u0430" },
            { "gil", "\u0433\u0438\u043b\u0431\u0435\u0440\u0442\u0441\u043a\u0438" },
            { "Cher", "\u0427\u0435\u0440\u043e\u043a\u0438" },
            { "car", "\u043a\u0430\u0440\u0438\u0431\u0441\u043a\u0438" },
            { "type.nu.tamldec", "\u0442\u0430\u043c\u0438\u043b\u0441\u043a\u0438 \u0446\u0438\u0444\u0440\u0438" },
            { "krc", "\u043a\u0430\u0440\u0430\u0447\u0430\u0439-\u0431\u0430\u043b\u043a\u0430\u0440\u0441\u043a\u0438" },
            { "inh", "\u0438\u043d\u0433\u0443\u0448\u0435\u0442\u0441\u043a\u0438" },
            { "krl", "\u043a\u0430\u0440\u0435\u043b\u0441\u043a\u0438" },
            { "efi", "\u0435\u0444\u0438\u043a" },
            { "key.nu", "\u0446\u0438\u0444\u0440\u0438" },
            { "kru", "\u043a\u0443\u0440\u0443\u043a" },
            { "ksb", "\u0448\u0430\u043c\u0431\u0430\u043b\u0430" },
            { "Telu", metaValue_te },
            { "ksf", "\u0431\u0430\u0444\u0438\u044f" },
        };
        return data;
    }
}
